from .. import Provider as AddressProvider


class Provider(AddressProvider):
    building_number_formats = ("#", "##", "###", "#", "##", "###")

    street_suffixes = (
        "baan",
        "boulevard",
        "dreef",
        "hof",
        "laan",
        "pad",
        "ring",
        "singel",
        "steeg",
        "straat",
        "weg",
    )

    # the 4 digit numerical part of Dutch postcodes is between 1000 and 9999;
    # see http://nl.wikipedia.org/wiki/Postcode#Postcodes_in_Nederland
    postcode_formats = ("%###??", "%### ??")

    city_formats = ("{{city}}",)

    # countries are from http://nl.wikipedia.org/wiki/ISO_3166-1
    countries = (
        "Afghanistan",
        "Albanië",
        "Algerije",
        "Amerikaans-Samoa",
        "Amerikaanse Maagdeneilanden",
        "Andorra",
        "Angola",
        "Anguilla",
        "Antarctica",
        "Antigua en Barbuda",
        "Argentinië",
        "Armenië",
        "Aruba",
        "Australië",
        "Azerbeidzjan",
        "Bahama's",
        "Bahrein",
        "Bangladesh",
        "Barbados",
        "België",
        "Belize",
        "Benin",
        "Bermuda",
        "Bhutan",
        "Bolivia",
        "Bonaire, Sint Eustatius en Saba",
        "Bosnië en Herzegovina",
        "Botswana",
        "Bouveteiland",
        "Brazilië",
        "Brits Indische Oceaanterritorium",
        "Britse Maagdeneilanden",
        "Brunei",
        "Bulgarije",
        "Burkina Faso",
        "Burundi",
        "Cambodja",
        "Canada",
        "Centraal-Afrikaanse Republiek",
        "Chili",
        "China",
        "Christmaseiland",
        "Cocoseilanden",
        "Colombia",
        "Comoren",
        "Congo-Brazzaville",
        "Congo-Kinshasa",
        "Cookeilanden",
        "Costa Rica",
        "Cuba",
        "Curaçao",
        "Cyprus",
        "Denemarken",
        "Djibouti",
        "Dominica",
        "Dominicaanse Republiek",
        "Duitsland",
        "Ecuador",
        "Egypte",
        "El Salvador",
        "Equatoriaal-Guinea",
        "Eritrea",
        "Estland",
        "Ethiopië",
        "Faeröer",
        "Falklandeilanden",
        "Fiji",
        "Filipijnen",
        "Finland",
        "Frankrijk",
        "Frans-Guyana",
        "Frans-Polynesië",
        "Franse Zuidelijke en Antarctische Gebieden",
        "Gabon",
        "Gambia",
        "Georgië",
        "Ghana",
        "Gibraltar",
        "Grenada",
        "Griekenland",
        "Groenland",
        "Guadeloupe",
        "Guam",
        "Guatemala",
        "Guernsey",
        "Guinee",
        "Guinee-Bissau",
        "Guyana",
        "Haïti",
        "Heard en McDonaldeilanden",
        "Honduras",
        "Hongarije",
        "Hongkong",
        "IJsland",
        "Ierland",
        "India",
        "Indonesië",
        "Irak",
        "Iran",
        "Israël",
        "Italië",
        "Ivoorkust",
        "Jamaica",
        "Japan",
        "Jemen",
        "Jersey",
        "Jordanië",
        "Kaaimaneilanden",
        "Kaapverdië",
        "Kameroen",
        "Kazachstan",
        "Kenia",
        "Kirgizië",
        "Kiribati",
        "Kleine Pacifische eilanden van de Verenigde Staten",
        "Koeweit",
        "Kroatië",
        "Laos",
        "Lesotho",
        "Letland",
        "Libanon",
        "Liberia",
        "Libië",
        "Liechtenstein",
        "Litouwen",
        "Luxemburg",
        "Macau",
        "Macedonië",
        "Madagaskar",
        "Malawi",
        "Maldiven",
        "Maleisië",
        "Mali",
        "Malta",
        "Man",
        "Marokko",
        "Marshalleilanden",
        "Martinique",
        "Mauritanië",
        "Mauritius",
        "Mayotte",
        "Mexico",
        "Micronesia",
        "Moldavië",
        "Monaco",
        "Mongolië",
        "Montenegro",
        "Montserrat",
        "Mozambique",
        "Myanmar",
        "Namibië",
        "Nauru",
        "Nederland",
        "Nepal",
        "Nicaragua",
        "Nieuw-Caledonië",
        "Nieuw-Zeeland",
        "Niger",
        "Nigeria",
        "Niue",
        "Noord-Korea",
        "Noordelijke Marianen",
        "Noorwegen",
        "Norfolk",
        "Oeganda",
        "Oekraïne",
        "Oezbekistan",
        "Oman",
        "Oost-Timor",
        "Oostenrijk",
        "Pakistan",
        "Palau",
        "Palestina",
        "Panama",
        "Papoea-Nieuw-Guinea",
        "Paraguay",
        "Peru",
        "Pitcairneilanden",
        "Polen",
        "Portugal",
        "Puerto Rico",
        "Qatar",
        "Roemenië",
        "Rusland",
        "Rwanda",
        "Réunion",
        "Saint Kitts en Nevis",
        "Saint Lucia",
        "Saint Vincent en de Grenadines",
        "Saint-Barthélemy",
        "Saint-Pierre en Miquelon",
        "Salomonseilanden",
        "Samoa",
        "San Marino",
        "Sao Tomé en Principe",
        "Saoedi-Arabië",
        "Senegal",
        "Servië",
        "Seychellen",
        "Sierra Leone",
        "Singapore",
        "Sint Maarten",
        "Sint-Helena, Ascension en Tristan da Cunha",
        "Sint-Maarten",
        "Slovenië",
        "Slowakije",
        "Soedan",
        "Somalië",
        "Spanje",
        "Spitsbergen en Jan Mayen",
        "Sri Lanka",
        "Suriname",
        "Swaziland",
        "Syrië",
        "Tadzjikistan",
        "Taiwan",
        "Tanzania",
        "Thailand",
        "Togo",
        "Tokelau",
        "Tonga",
        "Trinidad en Tobago",
        "Tsjaad",
        "Tsjechië",
        "Tunesië",
        "Turkije",
        "Turkmenistan",
        "Turks- en Caicoseilanden",
        "Tuvalu",
        "Uruguay",
        "Vanuatu",
        "Vaticaanstad",
        "Venezuela",
        "Verenigd Koninkrijk",
        "Verenigde Arabische Emiraten",
        "Verenigde Staten",
        "Vietnam",
        "Wallis en Futuna",
        "Westelijke Sahara",
        "Wit-Rusland",
        "Zambia",
        "Zimbabwe",
        "Zuid-Afrika",
        "Zuid-Georgia en de Zuidelijke Sandwicheilanden",
        "Zuid-Korea",
        "Zuid-Soedan",
        "Zweden",
        "Zwitserland",
        "Åland",
    )

    # cities are taken from the BAG "woonplaats";
    # in this case the 8-Mar-2014 extract;
    # see http://data.nlextract.nl/bag/csv/
    cities = (
        "'s Gravenmoer",
        "'s-Graveland",
        "'s-Gravendeel",
        "'s-Gravenhage",
        "'s-Gravenpolder",
        "'s-Gravenzande",
        "'s-Heer Abtskerke",
        "'s-Heer Arendskerke",
        "'s-Heer Hendrikskinderen",
        "'s-Heerenberg",
        "'s-Heerenbroek",
        "'s-Heerenhoek",
        "'s-Hertogenbosch",
        "'t Goy",
        "'t Haantje",
        "'t Harde",
        "'t Loo Oldebroek",
        "'t Veld",
        "'t Waar",
        "'t Zand",
        "'t Zandt",
        "1e Exloërmond",
        "2e Exloërmond",
        "2e Valthermond",
        "Aadorp",
        "Aagtekerke",
        "Aalden",
        "Aalsmeer",
        "Aalsmeerderbrug",
        "Aalst",
        "Aalsum",
        "Aalten",
        "Aardenburg",
        "Aarlanderveen",
        "Aarle-Rixtel",
        "Aartswoud",
        "Abbega",
        "Abbekerk",
        "Abbenbroek",
        "Abbenes",
        "Abcoude",
        "Achlum",
        "Achterveld",
        "Achthuizen",
        "Achtmaal",
        "Acquoy",
        "Adorp",
        "Aduard",
        "Aerdenhout",
        "Aerdt",
        "Afferden",
        "Afferden L",
        "Agelo",
        "Akersloot",
        "Akkrum",
        "Akmarijp",
        "Albergen",
        "Alblasserdam",
        "Alde Leie",
        "Aldeboarn",
        "Aldtsjerk",
        "Alem",
        "Alkmaar",
        "Allingawier",
        "Almelo",
        "Almen",
        "Almere",
        "Almkerk",
        "Alphen",
        "Alphen aan den Rijn",
        "Alteveer",
        "Alteveer gem Hoogeveen",
        "Altforst",
        "Ambt Delden",
        "Ameide",
        "Amen",
        "America",
        "Amerongen",
        "Amersfoort",
        "Ammerstol",
        "Ammerzoden",
        "Amstelhoek",
        "Amstelveen",
        "Amstenrade",
        "Amsterdam",
        "Amsterdam-Duivendrecht",
        "Andel",
        "Andelst",
        "Anderen",
        "Andijk",
        "Ane",
        "Anerveen",
        "Anevelde",
        "Angeren",
        "Angerlo",
        "Anjum",
        "Ankeveen",
        "Anloo",
        "Anna Paulowna",
        "Annen",
        "Annerveenschekanaal",
        "Ansen",
        "Apeldoorn",
        "Appelscha",
        "Appeltern",
        "Appingedam",
        "Arcen",
        "Arkel",
        "Arnemuiden",
        "Arnhem",
        "Arriën",
        "Arum",
        "Asch",
        "Asperen",
        "Assen",
        "Assendelft",
        "Asten",
        "Augsbuurt",
        "Augustinusga",
        "Austerlitz",
        "Avenhorn",
        "Axel",
        "Azewijn",
        "Baaiduinen",
        "Baaium",
        "Baak",
        "Baambrugge",
        "Baard",
        "Baarland",
        "Baarle-Nassau",
        "Baarlo",
        "Baarn",
        "Baars",
        "Babberich",
        "Babyloniënbroek",
        "Bad Nieuweschans",
        "Badhoevedorp",
        "Baexem",
        "Baflo",
        "Bakel",
        "Bakhuizen",
        "Bakkeveen",
        "Balgoij",
        "Balinge",
        "Balk",
        "Balkbrug",
        "Balloo",
        "Balloërveld",
        "Ballum",
        "Baneheide",
        "Banholt",
        "Bant",
        "Bantega",
        "Barchem",
        "Barendrecht",
        "Barger-Compascuum",
        "Barneveld",
        "Barsingerhorn",
        "Basse",
        "Batenburg",
        "Bathmen",
        "Bavel",
        "Bavel AC",
        "Bears",
        "Bedum",
        "Beegden",
        "Beek",
        "Beek en Donk",
        "Beekbergen",
        "Beemte Broekland",
        "Beers NB",
        "Beerta",
        "Beerze",
        "Beerzerveld",
        "Beesd",
        "Beesel",
        "Beets",
        "Beetsterzwaag",
        "Beilen",
        "Beinsdorp",
        "Belfeld",
        "Bellingwolde",
        "Belt-Schutsloot",
        "Beltrum",
        "Bemelen",
        "Bemmel",
        "Beneden-Leeuwen",
        "Bennebroek",
        "Bennekom",
        "Benneveld",
        "Benningbroek",
        "Benschop",
        "Bentelo",
        "Benthuizen",
        "Bentveld",
        "Berg en Dal",
        "Berg en Terblijt",
        "Bergambacht",
        "Bergeijk",
        "Bergen (NH)",
        "Bergen L",
        "Bergen aan Zee",
        "Bergen op Zoom",
        "Bergentheim",
        "Bergharen",
        "Berghem",
        "Bergschenhoek",
        "Beringe",
        "Berkel en Rodenrijs",
        "Berkel-Enschot",
        "Berkenwoude",
        "Berkhout",
        "Berlicum",
        "Berltsum",
        "Bern",
        "Best",
        "Beugen",
        "Beuningen",
        "Beuningen Gld",
        "Beusichem",
        "Beutenaken",
        "Beverwijk",
        "Biddinghuizen",
        "Bierum",
        "Biervliet",
        "Biest-Houtakker",
        "Biezenmortel",
        "Biggekerke",
        "Bilthoven",
        "Bingelrade",
        "Bitgum",
        "Bitgummole",
        "Bladel",
        "Blankenham",
        "Blaricum",
        "Blauwestad",
        "Blauwhuis",
        "Bleiswijk",
        "Blesdijke",
        "Bleskensgraaf ca",
        "Blessum",
        "Blije",
        "Blijham",
        "Blitterswijck",
        "Bloemendaal",
        "Blokker",
        "Blokzijl",
        "Boazum",
        "Bocholtz",
        "Bodegraven",
        "Boekel",
        "Boelenslaan",
        "Boer",
        "Boerakker",
        "Boesingheliede",
        "Boijl",
        "Boksum",
        "Bolsward",
        "Bontebok",
        "Boornbergum",
        "Boornzwaag",
        "Borculo",
        "Borger",
        "Borgercompagnie",
        "Borgsweer",
        "Born",
        "Borne",
        "Bornerbroek",
        "Bornwird",
        "Borssele",
        "Bosch en Duin",
        "Boschoord",
        "Boskoop",
        "Bosschenhoofd",
        "Botlek Rotterdam",
        "Bourtange",
        "Boven-Leeuwen",
        "Bovenkarspel",
        "Bovensmilde",
        "Boxmeer",
        "Boxtel",
        "Braamt",
        "Brakel",
        "Brandwijk",
        "Brantgum",
        "Breda",
        "Bredevoort",
        "Breedenbroek",
        "Breezand",
        "Breezanddijk",
        "Breskens",
        "Breukelen",
        "Breukeleveen",
        "Brielle",
        "Briltil",
        "Britsum",
        "Britswert",
        "Broek",
        "Broek in Waterland",
        "Broek op Langedijk",
        "Broekhuizen",
        "Broekhuizenvorst",
        "Broekland",
        "Broeksterwâld",
        "Bronkhorst",
        "Bronneger",
        "Bronnegerveen",
        "Brouwershaven",
        "Bruchem",
        "Brucht",
        "Bruchterveld",
        "Bruinehaar",
        "Bruinisse",
        "Brummen",
        "Brunssum",
        "Bruntinge",
        "Buchten",
        "Budel",
        "Budel-Dorplein",
        "Budel-Schoot",
        "Buggenum",
        "Buinen",
        "Buinerveen",
        "Buitenkaag",
        "Buitenpost",
        "Bunde",
        "Bunne",
        "Bunnik",
        "Bunschoten-Spakenburg",
        "Burdaard",
        "Buren",
        "Burgerbrug",
        "Burgerveen",
        "Burgh-Haamstede",
        "Burgum",
        "Burgwerd",
        "Burum",
        "Bussum",
        "Buurmalsen",
        "Cadier en Keer",
        "Cadzand",
        "Callantsoog",
        "Capelle aan den IJssel",
        "Castelre",
        "Castenray",
        "Casteren",
        "Castricum",
        "Chaam",
        "Clinge",
        "Coevorden",
        "Colijnsplaat",
        "Collendoorn",
        "Colmschate",
        "Cornwerd",
        "Cothen",
        "Creil",
        "Cromvoirt",
        "Cruquius",
        "Cuijk",
        "Culemborg",
        "Daarle",
        "Daarlerveen",
        "Dalem",
        "Dalen",
        "Dalerpeel",
        "Dalerveen",
        "Dalfsen",
        "Dalmsholte",
        "Damwâld",
        "Darp",
        "De Bilt",
        "De Blesse",
        "De Bult",
        "De Cocksdorp",
        "De Falom",
        "De Glind",
        "De Goorn",
        "De Groeve",
        "De Heen",
        "De Heurne",
        "De Hoeve",
        "De Kiel",
        "De Klomp",
        "De Knipe",
        "De Koog",
        "De Krim",
        "De Kwakel",
        "De Lier",
        "De Meern",
        "De Moer",
        "De Mortel",
        "De Pol",
        "De Punt",
        "De Rijp",
        "De Rips",
        "De Schiphorst",
        "De Steeg",
        "De Tike",
        "De Veenhoop",
        "De Waal",
        "De Weere",
        "De Westereen",
        "De Wilgen",
        "De Wilp",
        "De Zilk",
        "Dearsum",
        "Dedemsvaart",
        "Dedgum",
        "Deelen",
        "Deest",
        "Deil",
        "Deinum",
        "Delden",
        "Delfgauw",
        "Delfstrahuizen",
        "Delft",
        "Delfzijl",
        "Delwijnen",
        "Demen",
        "Den Andel",
        "Den Bommel",
        "Den Burg",
        "Den Dolder",
        "Den Dungen",
        "Den Ham",
        "Den Helder",
        "Den Hoorn",
        "Den Horn",
        "Den Hout",
        "Den Ilp",
        "Den Oever",
        "Den Velde",
        "Denekamp",
        "Deurne",
        "Deurningen",
        "Deursen-Dennenburg",
        "Deurze",
        "Deventer",
        "Didam",
        "Dieden",
        "Diemen",
        "Diepenheim",
        "Diepenveen",
        "Dieren",
        "Diessen",
        "Diever",
        "Dieverbrug",
        "Diffelen",
        "Dijken",
        "Dinteloord",
        "Dinxperlo",
        "Diphoorn",
        "Dirkshorn",
        "Dirksland",
        "Dodewaard",
        "Doenrade",
        "Doesburg",
        "Doetinchem",
        "Doeveren",
        "Doezum",
        "Dokkum",
        "Doldersum",
        "Domburg",
        "Donderen",
        "Dongen",
        "Dongjum",
        "Doniaga",
        "Donkerbroek",
        "Doorn",
        "Doornenburg",
        "Doornspijk",
        "Doorwerth",
        "Dordrecht",
        "Dorst",
        "Drachten",
        "Drachten-Azeven",
        "Drachtstercompagnie",
        "Dreischor",
        "Drempt",
        "Dreumel",
        "Driebergen-Rijsenburg",
        "Drieborg",
        "Driebruggen",
        "Driehuis NH",
        "Driehuizen",
        "Driel",
        "Driewegen",
        "Driezum",
        "Drijber",
        "Drimmelen",
        "Drogeham",
        "Drogteropslagen",
        "Drongelen",
        "Dronryp",
        "Dronten",
        "Drouwen",
        "Drouwenermond",
        "Drouwenerveen",
        "Drunen",
        "Druten",
        "Duiven",
        "Duivendrecht",
        "Duizel",
        "Dussen",
        "Dwingeloo",
        "Eagum",
        "Earnewâld",
        "Easterein",
        "Easterlittens",
        "Eastermar",
        "Easterwierrum",
        "Echt",
        "Echteld",
        "Echten",
        "Echtenerbrug",
        "Eck en Wiel",
        "Eckelrade",
        "Edam",
        "Ede",
        "Ederveen",
        "Ee",
        "Eede",
        "Eefde",
        "Eelde",
        "Eelderwolde",
        "Eemdijk",
        "Eemnes",
        "Eemshaven",
        "Een",
        "Een-West",
        "Eenrum",
        "Eenum",
        "Eerbeek",
        "Eersel",
        "Ees",
        "Eesergroen",
        "Eeserveen",
        "Eesterga",
        "Eesveen",
        "Eethen",
        "Eext",
        "Eexterveen",
        "Eexterveenschekanaal",
        "Eexterzandvoort",
        "Egchel",
        "Egmond aan Zee",
        "Egmond aan den Hoef",
        "Egmond-Binnen",
        "Eibergen",
        "Eijsden",
        "Eindhoven",
        "Einighausen",
        "Ekehaar",
        "Elahuizen",
        "Elburg",
        "Eldersloo",
        "Eleveld",
        "Elim",
        "Elkenrade",
        "Ell",
        "Ellecom",
        "Ellemeet",
        "Ellertshaar",
        "Ellewoutsdijk",
        "Elp",
        "Elsendorp",
        "Elshout",
        "Elsloo",
        "Elspeet",
        "Elst",
        "Elst Ut",
        "Emmeloord",
        "Emmen",
        "Emmer-Compascuum",
        "Empe",
        "Emst",
        "Engwierum",
        "Enkhuizen",
        "Ens",
        "Enschede",
        "Enspijk",
        "Enter",
        "Enumatil",
        "Epe",
        "Epen",
        "Eppenhuizen",
        "Epse",
        "Erica",
        "Erichem",
        "Erlecom",
        "Erm",
        "Ermelo",
        "Erp",
        "Esbeek",
        "Esch",
        "Escharen",
        "Espel",
        "Est",
        "Etten",
        "Etten-Leur",
        "Europoort Rotterdam",
        "Eursinge",
        "Everdingen",
        "Evertsoord",
        "Ewijk",
        "Exloo",
        "Exloërveen",
        "Exmorra",
        "Eygelshoven",
        "Eys",
        "Ezinge",
        "Farmsum",
        "Feanwâlden",
        "Feerwerd",
        "Feinsum",
        "Ferwert",
        "Ferwoude",
        "Fijnaart",
        "Finsterwolde",
        "Firdgum",
        "Fleringen",
        "Fluitenberg",
        "Fochteloo",
        "Follega",
        "Folsgare",
        "Formerum",
        "Foudgum",
        "Foxhol",
        "Foxwolde",
        "Franeker",
        "Frederiksoord",
        "Friens",
        "Frieschepalen",
        "Froombosch",
        "Gaanderen",
        "Gaast",
        "Gaastmeer",
        "Galder",
        "Gameren",
        "Gapinge",
        "Garderen",
        "Garmerwolde",
        "Garminge",
        "Garnwerd",
        "Garrelsweer",
        "Garsthuizen",
        "Garyp",
        "Gassel",
        "Gasselte",
        "Gasselternijveen",
        "Gasselternijveenschemond",
        "Gastel",
        "Gasteren",
        "Gauw",
        "Geelbroek",
        "Geerdijk",
        "Geersdijk",
        "Geertruidenberg",
        "Geervliet",
        "Gees",
        "Geesbrug",
        "Geesteren",
        "Geeuwenbrug",
        "Geffen",
        "Geijsteren",
        "Geldermalsen",
        "Gelderswoude",
        "Geldrop",
        "Geleen",
        "Gellicum",
        "Gelselaar",
        "Gemert",
        "Gemonde",
        "Genderen",
        "Gendringen",
        "Gendt",
        "Genemuiden",
        "Gennep",
        "Gerkesklooster",
        "Gersloot",
        "Geulle",
        "Giesbeek",
        "Giessen",
        "Giessenburg",
        "Gieten",
        "Gieterveen",
        "Giethmen",
        "Giethoorn",
        "Gilze",
        "Ginnum",
        "Glane",
        "Glimmen",
        "Godlinze",
        "Goedereede",
        "Goes",
        "Goingarijp",
        "Goirle",
        "Goor",
        "Gorinchem",
        "Gorredijk",
        "Gorssel",
        "Gouda",
        "Gouderak",
        "Goudriaan",
        "Goudswaard",
        "Goutum",
        "Goënga",
        "Goëngahuizen",
        "Graauw",
        "Grafhorst",
        "Graft",
        "Gramsbergen",
        "Grashoek",
        "Grathem",
        "Grave",
        "Greonterp",
        "Grevenbicht",
        "Griendtsveen",
        "Grijpskerk",
        "Grijpskerke",
        "Groede",
        "Groenekan",
        "Groeningen",
        "Groenlo",
        "Groesbeek",
        "Groessen",
        "Groet",
        "Grolloo",
        "Groningen",
        "Gronsveld",
        "Groot-Ammers",
        "Grootebroek",
        "Grootegast",
        "Grootschermer",
        "Grou",
        "Grubbenvorst",
        "Gulpen",
        "Guttecoven",
        "Gytsjerk",
        "Haaften",
        "Haaksbergen",
        "Haalderen",
        "Haaren",
        "Haarle",
        "Haarlem",
        "Haarlemmerliede",
        "Haarlo",
        "Haarsteeg",
        "Haarzuilens",
        "Haastrecht",
        "Haelen",
        "Hagestein",
        "Haghorst",
        "Haler",
        "Halfweg",
        "Hall",
        "Halle",
        "Hallum",
        "Halsteren",
        "Handel",
        "Hank",
        "Hansweert",
        "Hantum",
        "Hantumeruitburen",
        "Hantumhuizen",
        "Hapert",
        "Haps",
        "Harbrinkhoek",
        "Hardenberg",
        "Harderwijk",
        "Hardinxveld-Giessendam",
        "Haren",
        "Haren Gn",
        "Harfsen",
        "Harich",
        "Haringhuizen",
        "Harkema",
        "Harkstede",
        "Harlingen",
        "Harmelen",
        "Harreveld",
        "Harskamp",
        "Hartwerd",
        "Haskerdijken",
        "Haskerhorne",
        "Hasselt",
        "Hattem",
        "Hattemerbroek",
        "Haule",
        "Haulerwijk",
        "Hauwert",
        "Havelte",
        "Havelterberg",
        "Hazerswoude-Dorp",
        "Hazerswoude-Rijndijk",
        "Hedel",
        "Hedikhuizen",
        "Hee",
        "Heeg",
        "Heel",
        "Heelsum",
        "Heelweg",
        "Heemserveen",
        "Heemskerk",
        "Heemstede",
        "Heenvliet",
        "Heerde",
        "Heerenveen",
        "Heerewaarden",
        "Heerhugowaard",
        "Heerjansdam",
        "Heerle",
        "Heerlen",
        "Heesbeen",
        "Heesch",
        "Heesselt",
        "Heeswijk-Dinther",
        "Heeten",
        "Heeze",
        "Hegebeintum",
        "Hegelsom",
        "Hei- en Boeicop",
        "Heibloem",
        "Heide",
        "Heijen",
        "Heijenrath",
        "Heijningen",
        "Heikant",
        "Heilig Landstichting",
        "Heiligerlee",
        "Heiloo",
        "Heinenoord",
        "Heinkenszand",
        "Heino",
        "Hekelingen",
        "Hekendorp",
        "Helden",
        "Helenaveen",
        "Hellendoorn",
        "Hellevoetsluis",
        "Hellouw",
        "Hellum",
        "Helmond",
        "Helvoirt",
        "Hem",
        "Hemelum",
        "Hemmen",
        "Hempens",
        "Hemrik",
        "Hendrik-Ido-Ambacht",
        "Hengelo",
        "Hengelo (Gld)",
        "Hengevelde",
        "Hengstdijk",
        "Hensbroek",
        "Herbaijum",
        "Herkenbosch",
        "Herkingen",
        "Hernen",
        "Herpen",
        "Herpt",
        "Herten",
        "Hertme",
        "Herveld",
        "Herwen",
        "Herwijnen",
        "Heteren",
        "Heukelom",
        "Heukelum",
        "Heumen",
        "Heusden",
        "Heveadorp",
        "Heythuysen",
        "Hezingen",
        "Hiaure",
        "Hichtum",
        "Hidaard",
        "Hierden",
        "Hieslum",
        "Hijken",
        "Hijum",
        "Hilaard",
        "Hillegom",
        "Hilvarenbeek",
        "Hilversum",
        "Hindeloopen",
        "Hinnaard",
        "Hippolytushoef",
        "Hitzum",
        "Hobrede",
        "Hoedekenskerke",
        "Hoek",
        "Hoek van Holland",
        "Hoenderloo",
        "Hoensbroek",
        "Hoenzadriel",
        "Hoevelaken",
        "Hoeven",
        "Hoge Hexel",
        "Hollandsche Rading",
        "Hollandscheveld",
        "Hollum",
        "Holsloot",
        "Holten",
        "Holthees",
        "Holtheme",
        "Holthone",
        "Holtum",
        "Holwerd",
        "Holwierde",
        "Hommerts",
        "Homoet",
        "Honselersdijk",
        "Hoofddorp",
        "Hoofdplaat",
        "Hoog Soeren",
        "Hoog-Keppel",
        "Hoogblokland",
        "Hooge Mierde",
        "Hooge Zwaluwe",
        "Hoogeloon",
        "Hoogenweg",
        "Hoogerheide",
        "Hoogersmilde",
        "Hoogeveen",
        "Hoogezand",
        "Hooghalen",
        "Hoogkarspel",
        "Hoogland",
        "Hooglanderveen",
        "Hoogmade",
        "Hoogvliet Rotterdam",
        "Hoogwoud",
        "Hoorn",
        "Hoornaar",
        "Hoornsterzwaag",
        "Horn",
        "Hornhuizen",
        "Horssen",
        "Horst",
        "Houten",
        "Houtigehage",
        "Houwerzijl",
        "Huijbergen",
        "Huis ter Heide",
        "Huisduinen",
        "Huisseling",
        "Huissen",
        "Huizen",
        "Huizinge",
        "Hulsberg",
        "Hulsel",
        "Hulshorst",
        "Hulst",
        "Hulten",
        "Hummelo",
        "Hunsel",
        "Hurdegaryp",
        "Hurwenen",
        "Húns",
        "IJhorst",
        "IJlst",
        "IJmuiden",
        "IJsselham",
        "IJsselmuiden",
        "IJsselstein",
        "IJzendijke",
        "IJzendoorn",
        "Idaerd",
        "Idsegahuizum",
        "Idskenhuizen",
        "Idzega",
        "Iens",
        "Ilpendam",
        "Indijk",
        "Ingber",
        "Ingelum",
        "Ingen",
        "It Heidenskip",
        "Itens",
        "Ittervoort",
        "Jaarsveld",
        "Jabeek",
        "Jannum",
        "Jellum",
        "Jelsum",
        "Jirnsum",
        "Jislum",
        "Jisp",
        "Jistrum",
        "Jonkerslân",
        "Jonkersvaart",
        "Joppe",
        "Jorwert",
        "Joure",
        "Jouswier",
        "Jubbega",
        "Julianadorp",
        "Jutrijp",
        "Kaag",
        "Kaard",
        "Kaatsheuvel",
        "Kalenberg",
        "Kallenkote",
        "Kamerik",
        "Kampen",
        "Kamperland",
        "Kamperveen",
        "Kantens",
        "Kapel Avezaath",
        "Kapel-Avezaath",
        "Kapelle",
        "Kapellebrug",
        "Katlijk",
        "Kats",
        "Kattendijke",
        "Katwijk",
        "Katwijk NB",
        "Katwoude",
        "Kedichem",
        "Keent",
        "Keijenborg",
        "Kekerdom",
        "Kelpen-Oler",
        "Kerk Avezaath",
        "Kerk-Avezaath",
        "Kerkdriel",
        "Kerkenveld",
        "Kerkrade",
        "Kerkwerve",
        "Kerkwijk",
        "Kessel",
        "Kesteren",
        "Kiel-Windeweer",
        "Kilder",
        "Kimswerd",
        "Kinderdijk",
        "Kinnum",
        "Klaaswaal",
        "Klarenbeek",
        "Klazienaveen",
        "Klazienaveen-Noord",
        "Klein Zundert",
        "Klijndijk",
        "Klimmen",
        "Kloetinge",
        "Klooster Lidlum",
        "Kloosterburen",
        "Kloosterhaar",
        "Kloosterzande",
        "Klundert",
        "Knegsel",
        "Koarnjum",
        "Kockengen",
        "Koedijk",
        "Koekange",
        "Koewacht",
        "Kolderwolde",
        "Kolham",
        "Kolhorn",
        "Kollum",
        "Kollumerpomp",
        "Kollumerzwaag",
        "Kommerzijl",
        "Koningsbosch",
        "Koningslust",
        "Koog aan de Zaan",
        "Koolwijk",
        "Kootstertille",
        "Kootwijk",
        "Kootwijkerbroek",
        "Kornhorn",
        "Kornwerderzand",
        "Kortehemmen",
        "Kortenhoef",
        "Kortgene",
        "Koudekerk aan den Rijn",
        "Koudekerke",
        "Koudum",
        "Koufurderrige",
        "Krabbendijke",
        "Kraggenburg",
        "Kreileroord",
        "Krewerd",
        "Krimpen aan de Lek",
        "Krimpen aan den IJssel",
        "Kring van Dorth",
        "Krommenie",
        "Kronenberg",
        "Kropswolde",
        "Kruiningen",
        "Kruisland",
        "Kudelstaart",
        "Kuinre",
        "Kuitaart",
        "Kwadendamme",
        "Kwadijk",
        "Kwintsheul",
        "Kûbaard",
        "Laag Zuthem",
        "Laag-Keppel",
        "Laag-Soeren",
        "Lage Mierde",
        "Lage Vuursche",
        "Lage Zwaluwe",
        "Lageland",
        "Lambertschaag",
        "Lamswaarde",
        "Landerum",
        "Landgraaf",
        "Landhorst",
        "Landsmeer",
        "Langbroek",
        "Langedijke",
        "Langelille",
        "Langelo",
        "Langenboom",
        "Langerak",
        "Langeveen",
        "Langeweg",
        "Langezwaag",
        "Langweer",
        "Laren",
        "Lathum",
        "Lattrop-Breklenkamp",
        "Lauwersoog",
        "Lauwerzijl",
        "Ledeacker",
        "Leek",
        "Leende",
        "Leens",
        "Leerbroek",
        "Leerdam",
        "Leermens",
        "Leersum",
        "Leeuwarden",
        "Legemeer",
        "Leiden",
        "Leiderdorp",
        "Leidschendam",
        "Leimuiden",
        "Leimuiderbrug",
        "Lekkerkerk",
        "Lekkum",
        "Lellens",
        "Lelystad",
        "Lemele",
        "Lemelerveld",
        "Lemiers",
        "Lemmer",
        "Lengel",
        "Lent",
        "Leons",
        "Lepelstraat",
        "Lettelbert",
        "Lettele",
        "Leunen",
        "Leur",
        "Leusden",
        "Leuth",
        "Leutingewolde",
        "Leuvenheim",
        "Leveroy",
        "Lewedorp",
        "Lexmond",
        "Lichtaard",
        "Lichtenvoorde",
        "Liempde",
        "Lienden",
        "Lierderholthuis",
        "Lieren",
        "Lierop",
        "Lies",
        "Lieshout",
        "Liessel",
        "Lievelde",
        "Lieveren",
        "Lijnden",
        "Limbricht",
        "Limmen",
        "Linde",
        "Linden",
        "Linne",
        "Linschoten",
        "Lioessens",
        "Lippenhuizen",
        "Lisse",
        "Lisserbroek",
        "Lith",
        "Lithoijen",
        "Lobith",
        "Lochem",
        "Loenen",
        "Loenen aan de Vecht",
        "Loenersloot",
        "Loerbeek",
        "Lollum",
        "Lomm",
        "Longerhouw",
        "Loo Gld",
        "Loon",
        "Loon op Zand",
        "Loosbroek",
        "Loosdrecht",
        "Loozen",
        "Lopik",
        "Lopikerkapel",
        "Loppersum",
        "Losdorp",
        "Losser",
        "Lottum",
        "Loënga",
        "Lucaswolde",
        "Luddeweer",
        "Luinjeberd",
        "Lunteren",
        "Lutjebroek",
        "Lutjegast",
        "Lutjewinkel",
        "Luttelgeest",
        "Lutten",
        "Luttenberg",
        "Luxwoude",
        "Luyksgestel",
        "Lytsewierrum",
        "Maarheeze",
        "Maarn",
        "Maarsbergen",
        "Maarssen",
        "Maartensdijk",
        "Maasbommel",
        "Maasbracht",
        "Maasbree",
        "Maasdam",
        "Maasdijk",
        "Maashees",
        "Maasland",
        "Maassluis",
        "Maastricht",
        "Maastricht-Airport",
        "Maasvlakte Rotterdam",
        "Macharen",
        "Made",
        "Makkinga",
        "Makkum",
        "Malden",
        "Mander",
        "Manderveen",
        "Mantgum",
        "Mantinge",
        "Maren-Kessel",
        "Margraten",
        "Maria Hoop",
        "Mariahout",
        "Mariaparochie",
        "Marijenkampen",
        "Mariënberg",
        "Mariënheem",
        "Mariënvelde",
        "Markelo",
        "Marken",
        "Markenbinnen",
        "Marknesse",
        "Marle",
        "Marrum",
        "Marsum",
        "Marum",
        "Marwijksoord",
        "Mastenbroek",
        "Matsloot",
        "Maurik",
        "Mechelen",
        "Medemblik",
        "Meeden",
        "Meedhuizen",
        "Meerkerk",
        "Meerlo",
        "Meerssen",
        "Meerstad",
        "Meeuwen",
        "Megchelen",
        "Megen",
        "Meijel",
        "Melderslo",
        "Melick",
        "Meliskerke",
        "Melissant",
        "Menaam",
        "Mensingeweer",
        "Meppel",
        "Meppen",
        "Merkelbeek",
        "Merselo",
        "Meteren",
        "Meterik",
        "Metslawier",
        "Mheer",
        "Middelaar",
        "Middelburg",
        "Middelharnis",
        "Middelie",
        "Middelstum",
        "Middenbeemster",
        "Middenmeer",
        "Midlaren",
        "Midlum",
        "Midsland",
        "Midwolda",
        "Midwolde",
        "Midwoud",
        "Miedum",
        "Mierlo",
        "Mijdrecht",
        "Mijnsheerenland",
        "Mildam",
        "Milheeze",
        "Mill",
        "Millingen aan de Rijn",
        "Milsbeek",
        "Minnertsga",
        "Mirns",
        "Moddergat",
        "Moerdijk",
        "Moergestel",
        "Moerkapelle",
        "Moerstraten",
        "Molenaarsgraaf",
        "Molenhoek",
        "Molenschot",
        "Molkwerum",
        "Monnickendam",
        "Monster",
        "Montfoort",
        "Montfort",
        "Mook",
        "Mookhoek",
        "Moordrecht",
        "Moorveld",
        "Morra",
        "Muiden",
        "Muiderberg",
        "Munnekeburen",
        "Munnekezijl",
        "Munstergeleen",
        "Muntendam",
        "Mussel",
        "Musselkanaal",
        "Mûnein",
        "Naaldwijk",
        "Naarden",
        "Nagele",
        "Nederasselt",
        "Nederhemert",
        "Nederhorst den Berg",
        "Nederland",
        "Nederweert",
        "Nederweert-Eind",
        "Neede",
        "Neer",
        "Neerijnen",
        "Neeritter",
        "Neerkant",
        "Neerlangel",
        "Neerloon",
        "Nes",
        "Netersel",
        "Netterden",
        "Niawier",
        "Nibbixwoud",
        "Niebert",
        "Niehove",
        "Niekerk",
        "Nietap",
        "Nieuw Annerveen",
        "Nieuw Beerta",
        "Nieuw Heeten",
        "Nieuw Namen",
        "Nieuw Scheemda",
        "Nieuw- en Sint Joosland",
        "Nieuw-Amsterdam",
        "Nieuw-Balinge",
        "Nieuw-Beijerland",
        "Nieuw-Buinen",
        "Nieuw-Dordrecht",
        "Nieuw-Lekkerland",
        "Nieuw-Roden",
        "Nieuw-Schoonebeek",
        "Nieuw-Vennep",
        "Nieuw-Vossemeer",
        "Nieuw-Weerdinge",
        "Nieuwaal",
        "Nieuwdorp",
        "Nieuwe Niedorp",
        "Nieuwe Pekela",
        "Nieuwe Wetering",
        "Nieuwe-Tonge",
        "Nieuwebrug",
        "Nieuwediep",
        "Nieuwegein",
        "Nieuwehorne",
        "Nieuwendijk",
        "Nieuwer Ter Aa",
        "Nieuwerbrug aan den Rijn",
        "Nieuwerkerk",
        "Nieuwerkerk aan den IJssel",
        "Nieuweroord",
        "Nieuwersluis",
        "Nieuweschoot",
        "Nieuwkoop",
        "Nieuwkuijk",
        "Nieuwland",
        "Nieuwlande",
        "Nieuwlande Coevorden",
        "Nieuwleusen",
        "Nieuwolda",
        "Nieuwpoort",
        "Nieuwstadt",
        "Nieuwveen",
        "Nieuwvliet",
        "Niezijl",
        "Niftrik",
        "Nigtevecht",
        "Nij Altoenae",
        "Nij Beets",
        "Nijbroek",
        "Nijeberkoop",
        "Nijega",
        "Nijehaske",
        "Nijeholtpade",
        "Nijeholtwolde",
        "Nijelamer",
        "Nijemirdum",
        "Nijensleek",
        "Nijetrijne",
        "Nijeveen",
        "Nijhuizum",
        "Nijkerk",
        "Nijkerkerveen",
        "Nijland",
        "Nijlande",
        "Nijmegen",
        "Nijverdal",
        "Nispen",
        "Nisse",
        "Nistelrode",
        "Noardburgum",
        "Nooitgedacht",
        "Noorbeek",
        "Noord-Scharwoude",
        "Noord-Sleen",
        "Noordbeemster",
        "Noordbroek",
        "Noordeinde",
        "Noordeinde Gld",
        "Noordeloos",
        "Noorden",
        "Noordgouwe",
        "Noordhoek",
        "Noordhorn",
        "Noordlaren",
        "Noordscheschut",
        "Noordwelle",
        "Noordwijk",
        "Noordwijkerhout",
        "Noordwolde",
        "Nootdorp",
        "Norg",
        "Notter",
        "Nuenen",
        "Nuis",
        "Nuland",
        "Numansdorp",
        "Nunhem",
        "Nunspeet",
        "Nuth",
        "Nutter",
        "Obbicht",
        "Obdam",
        "Ochten",
        "Odijk",
        "Odiliapeel",
        "Odoorn",
        "Odoornerveen",
        "Oeffelt",
        "Oegstgeest",
        "Oene",
        "Oentsjerk",
        "Offingawier",
        "Ohé en Laak",
        "Oijen",
        "Oirlo",
        "Oirsbeek",
        "Oirschot",
        "Oisterwijk",
        "Okkenbroek",
        "Olburgen",
        "Oldeberkoop",
        "Oldebroek",
        "Oldeholtpade",
        "Oldeholtwolde",
        "Oldehove",
        "Oldekerk",
        "Oldelamer",
        "Oldemarkt",
        "Oldenzaal",
        "Oldenzijl",
        "Oldeouwer",
        "Oldetrijne",
        "Olst",
        "Olterterp",
        "Ommel",
        "Ommen",
        "Ommeren",
        "Onderdendam",
        "Onna",
        "Onnen",
        "Onstwedde",
        "Ooij",
        "Ooltgensplaat",
        "Oost West en Middelbeers",
        "Oost-Graftdijk",
        "Oost-Souburg",
        "Oostburg",
        "Oostdijk",
        "Oosteind",
        "Oosterbeek",
        "Oosterbierum",
        "Oosterblokker",
        "Oosterend",
        "Oosterhesselen",
        "Oosterhout",
        "Oosterland",
        "Oosterleek",
        "Oosternieland",
        "Oosternijkerk",
        "Oosterstreek",
        "Oosterwijk",
        "Oosterwijtwerd",
        "Oosterwolde",
        "Oosterwolde Gld",
        "Oosterzee",
        "Oosthem",
        "Oosthuizen",
        "Oostkapelle",
        "Oostknollendam",
        "Oostrum",
        "Oostvoorne",
        "Oostwold",
        "Oostwoud",
        "Oostzaan",
        "Ootmarsum",
        "Opeinde",
        "Opende",
        "Ophemert",
        "Opheusden",
        "Opijnen",
        "Oploo",
        "Opmeer",
        "Oppenhuizen",
        "Opperdoes",
        "Oranje",
        "Oranjewoud",
        "Orvelte",
        "Ospel",
        "Oss",
        "Ossendrecht",
        "Ossenisse",
        "Ossenwaard",
        "Ossenzijl",
        "Oterleek",
        "Otterlo",
        "Ottersum",
        "Ottoland",
        "Oud Ade",
        "Oud Annerveen",
        "Oud Gastel",
        "Oud Ootmarsum",
        "Oud Zuilen",
        "Oud-Alblas",
        "Oud-Beijerland",
        "Oud-Vossemeer",
        "Ouddorp",
        "Oude Meer",
        "Oude Niedorp",
        "Oude Pekela",
        "Oude Wetering",
        "Oude Willem",
        "Oude-Tonge",
        "Oudebildtzijl",
        "Oudega",
        "Oudehaske",
        "Oudehorne",
        "Oudelande",
        "Oudemirdum",
        "Oudemolen",
        "Oudenbosch",
        "Oudendijk",
        "Oudenhoorn",
        "Ouderkerk aan de Amstel",
        "Ouderkerk aan den IJssel",
        "Oudeschans",
        "Oudeschild",
        "Oudeschip",
        "Oudeschoot",
        "Oudesluis",
        "Oudewater",
        "Oudezijl",
        "Oudheusden",
        "Oudkarspel",
        "Oudorp",
        "Oudwoude",
        "Ouwerkerk",
        "Ouwster-Nijega",
        "Ouwsterhaule",
        "Overasselt",
        "Overberg",
        "Overdinkel",
        "Overlangel",
        "Overloon",
        "Overschild",
        "Overslag",
        "Overveen",
        "Ovezande",
        "Paasloo",
        "Paesens",
        "Pannerden",
        "Panningen",
        "Papekop",
        "Papendrecht",
        "Papenhoven",
        "Papenvoort",
        "Parrega",
        "Paterswolde",
        "Peest",
        "Peins",
        "Peize",
        "Peperga",
        "Pernis Rotterdam",
        "Persingen",
        "Pesse",
        "Petten",
        "Philippine",
        "Piaam",
        "Piershil",
        "Pieterburen",
        "Pietersbierum",
        "Pieterzijl",
        "Pijnacker",
        "Pingjum",
        "Plasmolen",
        "Poederoijen",
        "Poeldijk",
        "Polsbroek",
        "Poortugaal",
        "Poortvliet",
        "Poppenwier",
        "Posterholt",
        "Prinsenbeek",
        "Puiflijk",
        "Punthorst",
        "Purmer",
        "Purmerend",
        "Purmerland",
        "Puth",
        "Putte",
        "Putten",
        "Puttershoek",
        "Raalte",
        "Raamsdonk",
        "Raamsdonksveer",
        "Raard",
        "Radewijk",
        "Radio Kootwijk",
        "Raerd",
        "Randwijk",
        "Ransdaal",
        "Rasquert",
        "Ravenstein",
        "Ravenswaaij",
        "Ravenswoud",
        "Readtsjerk",
        "Reahûs",
        "Reduzum",
        "Reek",
        "Reeuwijk",
        "Reijmerstok",
        "Reitsum",
        "Rekken",
        "Renesse",
        "Renkum",
        "Renswoude",
        "Ressen",
        "Retranchement",
        "Reusel",
        "Reutum",
        "Reuver",
        "Rha",
        "Rheden",
        "Rhee",
        "Rheeze",
        "Rheezerveen",
        "Rhenen",
        "Rhenoy",
        "Rhoon",
        "Ridderkerk",
        "Ried",
        "Riel",
        "Rien",
        "Riethoven",
        "Rietmolen",
        "Rijen",
        "Rijkevoort",
        "Rijkevoort-De Walsert",
        "Rijnsaterwoude",
        "Rijnsburg",
        "Rijpwetering",
        "Rijs",
        "Rijsbergen",
        "Rijsenhout",
        "Rijssen",
        "Rijswijk",
        "Rijswijk (GLD)",
        "Rijswijk (NB)",
        "Rilland",
        "Rinsumageast",
        "Ritthem",
        "Rockanje",
        "Roden",
        "Roderesch",
        "Roderwolde",
        "Roelofarendsveen",
        "Roermond",
        "Rogat",
        "Roggel",
        "Rohel",
        "Rolde",
        "Roodeschool",
        "Roosendaal",
        "Roosteren",
        "Rosmalen",
        "Rossum",
        "Roswinkel",
        "Rotstergaast",
        "Rotsterhaule",
        "Rotterdam",
        "Rotterdam-Albrandswaard",
        "Rottevalle",
        "Rottum",
        "Rouveen",
        "Rozenburg",
        "Rozendaal",
        "Rucphen",
        "Ruigahuizen",
        "Ruinen",
        "Ruinerwold",
        "Rumpt",
        "Rutten",
        "Ruurlo",
        "Ryptsjerk",
        "Saaksum",
        "Saasveld",
        "Saaxumhuizen",
        "Sambeek",
        "Sandfirden",
        "Santpoort-Noord",
        "Santpoort-Zuid",
        "Sappemeer",
        "Sas van Gent",
        "Sassenheim",
        "Sauwerd",
        "Schagen",
        "Schagerbrug",
        "Schaijk",
        "Schalkhaar",
        "Schalkwijk",
        "Schalsum",
        "Schardam",
        "Scharendijke",
        "Scharmer",
        "Scharnegoutum",
        "Scharsterbrug",
        "Scharwoude",
        "Scheemda",
        "Scheerwolde",
        "Schellinkhout",
        "Schelluinen",
        "Schermerhorn",
        "Scherpenisse",
        "Scherpenzeel",
        "Schettens",
        "Scheulder",
        "Schiedam",
        "Schiermonnikoog",
        "Schijf",
        "Schijndel",
        "Schildwolde",
        "Schimmert",
        "Schin op Geul",
        "Schinnen",
        "Schinveld",
        "Schipborg",
        "Schiphol",
        "Schiphol-Rijk",
        "Schipluiden",
        "Schokland",
        "Schoondijke",
        "Schoonebeek",
        "Schoonhoven",
        "Schoonloo",
        "Schoonoord",
        "Schoonrewoerd",
        "Schoorl",
        "Schore",
        "Schouwerzijl",
        "Schraard",
        "Schuinesloot",
        "Sebaldeburen",
        "Sellingen",
        "Serooskerke",
        "Sevenum",
        "Sexbierum",
        "Sibculo",
        "Sibrandabuorren",
        "Sibrandahûs",
        "Siddeburen",
        "Siebengewald",
        "Siegerswoude",
        "Sijbekarspel",
        "Silvolde",
        "Simonshaven",
        "Simpelveld",
        "Sinderen",
        "Sint Agatha",
        "Sint Annen",
        "Sint Anthonis",
        "Sint Geertruid",
        "Sint Hubert",
        "Sint Jansklooster",
        "Sint Jansteen",
        "Sint Joost",
        "Sint Kruis",
        "Sint Maarten",
        "Sint Maartensbrug",
        "Sint Maartensvlotbrug",
        "Sint Nicolaasga",
        "Sint Odiliënberg",
        "Sint Pancras",
        "Sint Philipsland",
        "Sint-Annaland",
        "Sint-Maartensdijk",
        "Sint-Michielsgestel",
        "Sint-Oedenrode",
        "Sintjohannesga",
        "Sirjansland",
        "Sittard",
        "Skingen",
        "Slagharen",
        "Slappeterp",
        "Sleen",
        "Sleeuwijk",
        "Slenaken",
        "Sliedrecht",
        "Slijk-Ewijk",
        "Slijkenburg",
        "Slochteren",
        "Slootdorp",
        "Sloten",
        "Sluis",
        "Sluiskil",
        "Smakt",
        "Smalle Ee",
        "Smallebrugge",
        "Smilde",
        "Snakkerburen",
        "Sneek",
        "Snelrewaard",
        "Snikzwaag",
        "Soerendonk",
        "Soest",
        "Soesterberg",
        "Someren",
        "Sommelsdijk",
        "Son en Breugel",
        "Sondel",
        "Sonnega",
        "Spaarndam",
        "Spaarndam gem. Haarlem",
        "Spanbroek",
        "Spanga",
        "Spankeren",
        "Spannum",
        "Spaubeek",
        "Spier",
        "Spierdijk",
        "Spijk",
        "Spijk Gn",
        "Spijkenisse",
        "Spijkerboor",
        "Sprang-Capelle",
        "Sprundel",
        "Spui",
        "St. Willebrord",
        "St.-Annaparochie",
        "St.-Jacobiparochie",
        "Stad aan 't Haringvliet",
        "Stadskanaal",
        "Stampersgat",
        "Standdaarbuiten",
        "Staphorst",
        "Starnmeer",
        "Startenhuizen",
        "Stavenisse",
        "Stavoren",
        "Stedum",
        "Steenbergen",
        "Steendam",
        "Steenderen",
        "Steenenkamer",
        "Steensel",
        "Steenwijk",
        "Steenwijkerwold",
        "Stegeren",
        "Steggerda",
        "Stein",
        "Stellendam",
        "Sterksel",
        "Stevensbeek",
        "Stevensweert",
        "Steyl",
        "Stieltjeskanaal",
        "Stiens",
        "Stitswerd",
        "Stokkum",
        "Stolwijk",
        "Stompetoren",
        "Stoutenburg",
        "Stoutenburg Noord",
        "Stramproy",
        "Streefkerk",
        "Striep",
        "Strijbeek",
        "Strijen",
        "Strijensas",
        "Stroe",
        "Stroobos",
        "Stuifzand",
        "Sumar",
        "Surhuisterveen",
        "Surhuizum",
        "Susteren",
        "Suwâld",
        "Swalmen",
        "Sweikhuizen",
        "Swichum",
        "Swifterbant",
        "Swolgen",
        "Taarlo",
        "Teeffelen",
        "Teerns",
        "Tegelen",
        "Ten Boer",
        "Ten Post",
        "Ter Aar",
        "Ter Aard",
        "Ter Apel",
        "Ter Apelkanaal",
        "Ter Heijde",
        "Ter Idzard",
        "Terband",
        "Terborg",
        "Terheijden",
        "Terherne",
        "Terhole",
        "Terkaple",
        "Termunten",
        "Termunterzijl",
        "Ternaard",
        "Terneuzen",
        "Teroele",
        "Terschuur",
        "Tersoal",
        "Terwispel",
        "Terwolde",
        "Teteringen",
        "Teuge",
        "Thesinge",
        "Tholen",
        "Thorn",
        "Tiel",
        "Tiendeveen",
        "Tienhoven",
        "Tienray",
        "Tijnje",
        "Tilburg",
        "Tilligte",
        "Tinallinge",
        "Tinte",
        "Tirns",
        "Tjalhuizum",
        "Tjalleberd",
        "Tjerkgaast",
        "Tjerkwerd",
        "Tjuchem",
        "Tolbert",
        "Toldijk",
        "Tolkamer",
        "Tollebeek",
        "Tonden",
        "Toornwerd",
        "Tricht",
        "Triemen",
        "Tripscompagnie",
        "Tubbergen",
        "Tuil",
        "Tuitjenhorn",
        "Tuk",
        "Tull en 't Waal",
        "Twello",
        "Twijzel",
        "Twijzelerheide",
        "Twisk",
        "Tynaarlo",
        "Tytsjerk",
        "Tzum",
        "Tzummarum",
        "Ubbena",
        "Ubbergen",
        "Uddel",
        "Uden",
        "Udenhout",
        "Uffelte",
        "Ugchelen",
        "Uitdam",
        "Uitgeest",
        "Uithoorn",
        "Uithuizen",
        "Uithuizermeeden",
        "Uitwellingerga",
        "Uitwijk",
        "Ulestraten",
        "Ulft",
        "Ulicoten",
        "Ulrum",
        "Ulvenhout",
        "Ulvenhout AC",
        "Ureterp",
        "Urk",
        "Urmond",
        "Ursem",
        "Ursem gem. S",
        "Usquert",
        "Utrecht",
        "Vaals",
        "Vaassen",
        "Valburg",
        "Valkenburg",
        "Valkenswaard",
        "Valthe",
        "Valthermond",
        "Varik",
        "Varsselder",
        "Varsseveld",
        "Vasse",
        "Veelerveen",
        "Veen",
        "Veendam",
        "Veenendaal",
        "Veenhuizen",
        "Veeningen",
        "Veenklooster",
        "Veenoord",
        "Veere",
        "Veessen",
        "Vegelinsoord",
        "Veghel",
        "Velddriel",
        "Velden",
        "Veldhoven",
        "Velp",
        "Velsen-Noord",
        "Velsen-Zuid",
        "Velserbroek",
        "Ven-Zelderheide",
        "Venebrugge",
        "Venhorst",
        "Venhuizen",
        "Venlo",
        "Venray",
        "Vessem",
        "Vethuizen",
        "Veulen",
        "Vianen",
        "Vianen NB",
        "Vierakker",
        "Vierhouten",
        "Vierhuizen",
        "Vierlingsbeek",
        "Vierpolders",
        "Vijfhuizen",
        "Vijlen",
        "Vilsteren",
        "Vinkega",
        "Vinkel",
        "Vinkenbuurt",
        "Vinkeveen",
        "Visvliet",
        "Vlaardingen",
        "Vlagtwedde",
        "Vledder",
        "Vledderveen",
        "Vleuten",
        "Vlieland",
        "Vlierden",
        "Vlijmen",
        "Vlissingen",
        "Vlist",
        "Vlodrop",
        "Voerendaal",
        "Vogelenzang",
        "Vogelwaarde",
        "Volendam",
        "Volkel",
        "Vollenhove",
        "Vondelingenplaat Rotterdam",
        "Voorburg",
        "Voorhout",
        "Voorschoten",
        "Voorst",
        "Voorthuizen",
        "Vorchten",
        "Vorden",
        "Vorstenbosch",
        "Vortum-Mullem",
        "Vragender",
        "Vredenheim",
        "Vredepeel",
        "Vreeland",
        "Vries",
        "Vriescheloo",
        "Vriezenveen",
        "Vroomshoop",
        "Vrouwenakker",
        "Vrouwenparochie",
        "Vrouwenpolder",
        "Vught",
        "Vuren",
        "Waaksens",
        "Waal",
        "Waalre",
        "Waalwijk",
        "Waarde",
        "Waardenburg",
        "Waarder",
        "Waardhuizen",
        "Waarland",
        "Waaxens",
        "Wachtum",
        "Waddinxveen",
        "Wadenoijen",
        "Wagenberg",
        "Wagenborgen",
        "Wageningen",
        "Walem",
        "Walsoorden",
        "Wamel",
        "Wanneperveen",
        "Wanroij",
        "Wanssum",
        "Wapenveld",
        "Wapse",
        "Wapserveen",
        "Warder",
        "Warffum",
        "Warfhuizen",
        "Warfstermolen",
        "Warmenhuizen",
        "Warmond",
        "Warns",
        "Warnsveld",
        "Warstiens",
        "Warten",
        "Waskemeer",
        "Waspik",
        "Wassenaar",
        "Wateren",
        "Watergang",
        "Waterhuizen",
        "Wateringen",
        "Waterlandkerkje",
        "Waverveen",
        "Wedde",
        "Weerselo",
        "Weert",
        "Weesp",
        "Wehe-den Hoorn",
        "Wehl",
        "Weidum",
        "Weiteveen",
        "Wekerom",
        "Well",
        "Well L",
        "Wellerlooi",
        "Welsum",
        "Wemeldinge",
        "Wenum Wiesel",
        "Wergea",
        "Werkendam",
        "Werkhoven",
        "Wernhout",
        "Wervershoof",
        "Wesepe",
        "Wessem",
        "West-Graftdijk",
        "West-Terschelling",
        "Westbeemster",
        "Westbroek",
        "Westdorp",
        "Westdorpe",
        "Westendorp",
        "Westerbeek",
        "Westerbork",
        "Westerbroek",
        "Westeremden",
        "Westergeest",
        "Westerhaar-Vriezenveensewijk",
        "Westerhoven",
        "Westerland",
        "Westerlee",
        "Westernieland",
        "Westervelde",
        "Westervoort",
        "Westerwijtwerd",
        "Westhem",
        "Westhoek",
        "Westkapelle",
        "Westknollendam",
        "Westmaas",
        "Westwoud",
        "Westzaan",
        "Wetering",
        "Weteringbrug",
        "Wetsens",
        "Wetsinge",
        "Weurt",
        "Wezep",
        "Wezup",
        "Wezuperbrug",
        "Wichmond",
        "Wier",
        "Wierden",
        "Wieringerwaard",
        "Wieringerwerf",
        "Wierum",
        "Wijchen",
        "Wijckel",
        "Wijdenes",
        "Wijdewormer",
        "Wijhe",
        "Wijk aan Zee",
        "Wijk bij Duurstede",
        "Wijk en Aalburg",
        "Wijlre",
        "Wijnaldum",
        "Wijnandsrade",
        "Wijnbergen",
        "Wijngaarden",
        "Wijnjewoude",
        "Wijster",
        "Wilbertoord",
        "Wildervank",
        "Wilhelminadorp",
        "Wilhelminaoord",
        "Willemsoord",
        "Willemstad",
        "Wilnis",
        "Wilp",
        "Wilsum",
        "Winde",
        "Windraak",
        "Winkel",
        "Winneweer",
        "Winschoten",
        "Winssen",
        "Winsum",
        "Wintelre",
        "Winterswijk",
        "Winterswijk Brinkheurne",
        "Winterswijk Corle",
        "Winterswijk Henxel",
        "Winterswijk Huppel",
        "Winterswijk Kotten",
        "Winterswijk Meddo",
        "Winterswijk Miste",
        "Winterswijk Ratum",
        "Winterswijk Woold",
        "Wirdum",
        "Wirdum Gn",
        "Wissenkerke",
        "Witharen",
        "Witmarsum",
        "Witte Paarden",
        "Wittelte",
        "Wittem",
        "Witteveen",
        "Wiuwert",
        "Wjelsryp",
        "Woensdrecht",
        "Woerden",
        "Woerdense Verlaat",
        "Wognum",
        "Woldendorp",
        "Wolfheze",
        "Wolphaartsdijk",
        "Wolsum",
        "Woltersum",
        "Wolvega",
        "Wommels",
        "Wons",
        "Workum",
        "Wormer",
        "Wormerveer",
        "Woubrugge",
        "Woudbloem",
        "Woudenberg",
        "Woudrichem",
        "Woudsend",
        "Wouw",
        "Wouwse Plantage",
        "Wyns",
        "Wytgaard",
        "Wâlterswâld",
        "Wânswert",
        "Yde",
        "Yerseke",
        "Ypecolsga",
        "Ysbrechtum",
        "Ysselsteyn",
        "Zaamslag",
        "Zaandam",
        "Zaandijk",
        "Zalk",
        "Zaltbommel",
        "Zandberg",
        "Zandeweer",
        "Zandhuizen",
        "Zandpol",
        "Zandvoort",
        "Zeddam",
        "Zeegse",
        "Zeeland",
        "Zeerijp",
        "Zeewolde",
        "Zegge",
        "Zegveld",
        "Zeijen",
        "Zeijerveen",
        "Zeijerveld",
        "Zeist",
        "Zelhem",
        "Zenderen",
        "Zennewijnen",
        "Zetten",
        "Zevenaar",
        "Zevenbergen",
        "Zevenbergschen Hoek",
        "Zevenhoven",
        "Zevenhuizen",
        "Zierikzee",
        "Zieuwent",
        "Zijderveld",
        "Zijdewind",
        "Zijldijk",
        "Zoelen",
        "Zoelmond",
        "Zoetermeer",
        "Zoeterwoude",
        "Zonnemaire",
        "Zorgvlied",
        "Zoutelande",
        "Zoutkamp",
        "Zuid-Beijerland",
        "Zuid-Scharwoude",
        "Zuidbroek",
        "Zuiddorpe",
        "Zuidermeer",
        "Zuiderwoude",
        "Zuidhorn",
        "Zuidlaarderveen",
        "Zuidland",
        "Zuidlaren",
        "Zuidoostbeemster",
        "Zuidschermer",
        "Zuidveen",
        "Zuidveld",
        "Zuidvelde",
        "Zuidwolde",
        "Zuidzande",
        "Zuilichem",
        "Zuna",
        "Zundert",
        "Zurich",
        "Zutphen",
        "Zuurdijk",
        "Zwaag",
        "Zwaagdijk-Oost",
        "Zwaagdijk-West",
        "Zwaanshoek",
        "Zwagerbosch",
        "Zwammerdam",
        "Zwanenburg",
        "Zwartebroek",
        "Zwartemeer",
        "Zwartewaal",
        "Zwartsluis",
        "Zweeloo",
        "Zweins",
        "Zwiggelte",
        "Zwijndrecht",
        "Zwinderen",
        "Zwolle",
        "de Hoef",
        "de Lutte",
        "de Wijk",
        "de Woude",
    )

    provinces = (
        "Drenthe",
        "Flevoland",
        "Friesland",
        "Gelderland",
        "Groningen",
        "Limburg",
        "Noord-Brabant",
        "Noord-Holland",
        "Overijssel",
        "Utrecht",
        "Zeeland",
        "Zuid-Holland",
    )

    street_name_formats = ("{{first_name}}{{street_suffix}}",)

    street_address_formats = ("{{street_name}} {{building_number}}",)

    address_formats = ("{{street_address}}\n{{postcode}}\n{{city}}",)

    def administrative_unit(self) -> str:
        return self.random_element(self.provinces)

    province = administrative_unit

    def city(self) -> str:
        return self.random_element(self.cities)



from ..en import Provider as AddressProvider


class Provider(AddressProvider):

    city_prefixes = ("North", "East", "West", "South", "New", "Lake", "Port", "St.")

    city_suffixes = (
        "town",
        "ton",
        "land",
        "ville",
        "berg",
        "burgh",
        "borough",
        "bury",
        "view",
        "port",
        "mouth",
        "stad",
        "furt",
        "chester",
        "mouth",
        "fort",
        "haven",
        "side",
        "shire",
    )

    building_number_formats = ("###", "##", "#")

    street_suffixes = (
        "Access",
        "Alley",
        "Alleyway",
        "Amble",
        "Anchorage",
        "Approach",
        "Arcade",
        "Artery",
        "Avenue",
        "Basin",
        "Beach",
        "Bend",
        "Block",
        "Boulevard",
        "Brace",
        "Brae",
        "Break",
        "Bridge",
        "Broadway",
        "Brow",
        "Bypass",
        "Byway",
        "Causeway",
        "Centre",
        "Centreway",
        "Chase",
        "Circle",
        "Circlet",
        "Circuit",
        "Circus",
        "Close",
        "Colonnade",
        "Common",
        "Concourse",
        "Copse",
        "Corner",
        "Corso",
        "Court",
        "Courtyard",
        "Cove",
        "Crescent",
        "Crest",
        "Cross",
        "Crossing",
        "Crossroad",
        "Crossway",
        "Cruiseway",
        "Cul-de-sac",
        "Cutting",
        "Dale",
        "Dell",
        "Deviation",
        "Dip",
        "Distributor",
        "Drive",
        "Driveway",
        "Edge",
        "Elbow",
        "End",
        "Entrance",
        "Esplanade",
        "Estate",
        "Expressway",
        "Extension",
        "Fairway",
        "Fire Track",
        "Firetrail",
        "Flat",
        "Follow",
        "Footway",
        "Foreshore",
        "Formation",
        "Freeway",
        "Front",
        "Frontage",
        "Gap",
        "Garden",
        "Gardens",
        "Gate",
        "Gates",
        "Glade",
        "Glen",
        "Grange",
        "Green",
        "Ground",
        "Grove",
        "Gully",
        "Heights",
        "Highroad",
        "Highway",
        "Hill",
        "Interchange",
        "Intersection",
        "Junction",
        "Key",
        "Landing",
        "Lane",
        "Laneway",
        "Lees",
        "Line",
        "Link",
        "Little",
        "Lookout",
        "Loop",
        "Lower",
        "Mall",
        "Meander",
        "Mew",
        "Mews",
        "Motorway",
        "Mount",
        "Nook",
        "Outlook",
        "Parade",
        "Park",
        "Parklands",
        "Parkway",
        "Part",
        "Pass",
        "Path",
        "Pathway",
        "Piazza",
        "Place",
        "Plateau",
        "Plaza",
        "Pocket",
        "Point",
        "Port",
        "Promenade",
        "Quad",
        "Quadrangle",
        "Quadrant",
        "Quay",
        "Quays",
        "Ramble",
        "Ramp",
        "Range",
        "Reach",
        "Reserve",
        "Rest",
        "Retreat",
        "Ride",
        "Ridge",
        "Ridgeway",
        "Right Of Way",
        "Ring",
        "Rise",
        "River",
        "Riverway",
        "Riviera",
        "Road",
        "Roads",
        "Roadside",
        "Roadway",
        "Ronde",
        "Rosebowl",
        "Rotary",
        "Round",
        "Route",
        "Row",
        "Rue",
        "Run",
        "Service Way",
        "Siding",
        "Slope",
        "Sound",
        "Spur",
        "Square",
        "Stairs",
        "State Highway",
        "Steps",
        "Strand",
        "Street",
        "Strip",
        "Subway",
        "Tarn",
        "Terrace",
        "Thoroughfare",
        "Tollway",
        "Top",
        "Tor",
        "Towers",
        "Track",
        "Trail",
        "Trailer",
        "Triangle",
        "Trunkway",
        "Turn",
        "Underpass",
        "Upper",
        "Vale",
        "Viaduct",
        "View",
        "Villas",
        "Vista",
        "Wade",
        "Walk",
        "Walkway",
        "Way",
        "Wynd",
    )

    postcode_formats = (
        # as per https://en.wikipedia.org/wiki/Postcodes_in_Australia
        # NSW
        "1###",
        "20##",
        "21##",
        "22##",
        "23##",
        "24##",
        "25##",
        "2619",
        "262#",
        "263#",
        "264#",
        "265#",
        "266#",
        "267#",
        "268#",
        "269#",
        "27##",
        "28##",
        "292#",
        "293#",
        "294#",
        "295#",
        "296#",
        "297#",
        "298#",
        "299#",
        # ACT
        "02##",
        "260#",
        "261#",
        "290#",
        "291#",
        "2920",
        # VIC
        "3###",
        "8###",
        # QLD
        "4###",
        "9###",
        # SA
        "5###",
        # WA
        "6###",
        # TAS
        "7###",
        # NT
        "08##",
        "09##",
    )

    states = (
        "Australian Capital Territory",
        "New South Wales",
        "Northern Territory",
        "Queensland",
        "South Australia",
        "Tasmania",
        "Victoria",
        "Western Australia",
    )

    states_abbr = ("ACT", "NSW", "NT", "QLD", "SA", "TAS", "VIC", "WA")

    city_formats = (
        "{{city_prefix}} {{first_name}}{{city_suffix}}",
        "{{city_prefix}} {{first_name}}",
        "{{first_name}}{{city_suffix}}",
        "{{last_name}}{{city_suffix}}",
    )

    street_name_formats = (
        "{{first_name}} {{street_suffix}}",
        "{{last_name}} {{street_suffix}}",
    )

    street_address_formats = (
        "{{building_number}} {{street_name}}",
        "{{secondary_address}}{{building_number}} {{street_name}}",
    )

    address_formats = ("{{street_address}}\n{{city}}, {{state_abbr}}, {{postcode}}",)

    secondary_address_formats = (
        "Apt. ### ",
        "Flat ## ",
        "Suite ### ",
        "Unit ## ",
        "Level # ",
        "###/",
        "##/",
        "#/",
    )

    def city_prefix(self) -> str:
        return self.random_element(self.city_prefixes)

    def secondary_address(self) -> str:
        return self.numerify(self.random_element(self.secondary_address_formats))

    def administrative_unit(self) -> str:
        return self.random_element(self.states)

    state = administrative_unit

    def state_abbr(self) -> str:
        return self.random_element(self.states_abbr)



from typing import Tuple

from .. import Provider as AddressProvider


class Provider(AddressProvider):
    city_formats = ("{{canton_name}}",)
    building_number_formats = ("%", "%#", "%#", "%#", "%##")
    street_suffixes = ["strasse"]
    street_name_formats = ("{{last_name}}{{street_suffix}}",)
    street_address_formats = ("{{street_name}} {{building_number}}",)
    address_formats = ("{{street_address}}\n{{postcode}} {{city}}",)
    postcode_formats = (
        "1###",
        "2###",
        "3###",
        "4###",
        "5###",
        "6###",
        "7###",
        "8###",
        "9###",
    )

    cantons = (
        ("AG", "Aargau"),
        ("AI", "Appenzell Innerrhoden"),
        ("AR", "Appenzell Ausserrhoden"),
        ("BE", "Bern"),
        ("BL", "Basel-Landschaft"),
        ("BS", "Basel-Stadt"),
        ("FR", "Freiburg"),
        ("GE", "Genf"),
        ("GL", "Glarus"),
        ("GR", "Graubünden"),
        ("JU", "Jura"),
        ("LU", "Luzern"),
        ("NE", "Neuenburg"),
        ("NW", "Nidwalden"),
        ("OW", "Obwalden"),
        ("SG", "St. Gallen"),
        ("SH", "Schaffhausen"),
        ("SO", "Solothurn"),
        ("SZ", "Schwyz"),
        ("TG", "Thurgau"),
        ("TI", "Tessin"),
        ("UR", "Uri"),
        ("VD", "Waadt"),
        ("VS", "Wallis"),
        ("ZG", "Zug"),
        ("ZH", "Zürich"),
    )

    def canton(self) -> Tuple[str, str]:
        """
        Randomly returns a swiss canton ('Abbreviated', 'Name').
        :example ('ZH', 'Zürich')
        """
        return self.random_element(self.cantons)

    def administrative_unit(self) -> str:
        """
        Randomly returns a Swiss canton name.
        :example 'Zürich'
        """
        return self.canton()[1]

    canton_name = administrative_unit

    def canton_code(self) -> str:
        """
        Randomly returns a Swiss canton code.
        :example 'ZH'
        """
        return self.canton()[0]



from itertools import product

from ..en_US import Provider as EnUsBarcodeProvider


class Provider(EnUsBarcodeProvider):
    """Implement barcode provider for ``en_CA`` locale.

    Canada uses UPC as well, so there are similarities between this and the
    ``en_US`` implementation.

    Sources:

    - https://gs1.org/standards/id-keys/company-prefix
    - https://www.nationwidebarcode.com/upc-country-codes/
    """

    local_prefixes = (
        # Some sources do not specify prefixes 00~01, 06~09 for use in Canada,
        # but it's referenced in other pages
        *product((0,), range(2)),
        *product((0,), range(6, 10)),
        (7, 5),
    )



from .. import Provider as AddressProvider


class Provider(AddressProvider):
    city_formats = ["{{city_name}}"]
    street_name_formats = ["{{street_title}} {{street_suffix}}"]
    street_address_formats = ["{{street_name}} {{building_number}}"]
    address_formats = ["{{street_address}}, {{city}}"]
    building_number_formats = ["##"]
    street_suffixes = ["ქ."]

    # Source: Wikipedia's list of sovereign states
    # https://en.wikipedia.org/wiki/List_of_sovereign_states
    countries = (
        "ავსტრალია",
        "ავსტრია",
        "ავღანეთი",
        "აზერბაიჯანი",
        "ალბანეთი",
        "ალჟირი",
        "ამერიკის სამოა",
        "ამერიკის ვირჯინიის კუნძულები",
        "ამერიკის შეერთებული შტატები",
        "ანგილია",
        "ანგოლა",
        "ანდორა",
        "ანტიგუა და ბარბუდა",
        "არაბთა გაერთიანებული საამიროები",
        "არგენტინა",
        "არუბა",
        "აღმოსავლეთი ტიმორი",
        "ახალი ზელანდია",
        "ახალი კალედონია",
        "ბანგლადეში",
        "ბარბადოსი",
        "ბასას-და-ინდია",
        "ბაჰამის კუნძულები",
        "ბაჰრეინი",
        "ბელარუსი",
        "ბელგია",
        "ბელიზი",
        "ბენინი",
        "ბერმუდა",
        "ბოლივია",
        "ბოსნია და ჰერცეგოვინა",
        "ბოტსვანა",
        "ბრაზილია",
        "ბრიტანეთის ვირჯინიის კუნძულები",
        "ბრიტანეთის ინდოეთის ოკეანის ტერიტორია",
        "ბრუნეი",
        "ბულგარეთი",
        "ბურკინა ფასო",
        "ბურუნდი",
        "ბუვე",
        "ბჰუტანი",
        "გაბონი",
        "გაიანა",
        "გამბია",
        "განა",
        "გერმანია",
        "გვადელუპა",
        "გვატემალა",
        "გვინეა",
        "გვინეა-ბისაუ",
        "გიბრალტარი",
        "გრენადა",
        "გრენლანდია",
        "გუამი",
        "დანია",
        "დიდი ბრიტანეთი",
        "დომინიკელთა რესპუბლიკა",
        "დომინიკა",
        "ეგვიპტე",
        "ევროპა (კუნძული)",
        "ეთიოპია",
        "ეკვადორი",
        "ეკვატორული გვინეა",
        "ერაყი",
        "ერიტრეა",
        "ესპანეთი",
        "ესტონეთი",
        "ეშმორის და კარტიეს კუნძულები",
        "უოლისი და ფუტუნა",
        "ვანუატუ",
        "ვატიკანი",
        "ვენესუელა",
        "ვიეტნამი",
        "ზამბია",
        "ზიმბაბვე",
        "თურქეთი",
        "თურქმენეთი",
        "იამაიკა",
        "იან მაიენი",
        "იაპონია",
        "იემენი",
        "ინდოეთი",
        "ინდონეზია",
        "იორდანია",
        "ირანი",
        "ირლანდია",
        "ისლანდია",
        "ისრაელი",
        "იტალია",
        "კაბო-ვერდე",
        "კაიმანის კუნძულები",
        "კამბოჯა",
        "კამერუნი",
        "კანადა",
        "კატარი",
        "კენია",
        "კვიპროსი",
        "კინგმენის რიფი",
        "კირიბატი",
        "ქოქოსის კუნძულები",
        "კოლუმბია",
        "კომორის კუნძულები",
        "კონგოს დემოკრატიული რესპუბლიკა",
        "კონგოს რესპუბლიკა",
        "კორეის რესპუბლიკა",
        "ჩრდილოეთი კორეა",
        "კოსტა-რიკა",
        "კოტ-დ’ივუარი",
        "კუბა",
        "კუკის კუნძულები",
        "ლაოსი",
        "ლატვია",
        "ლესოთო",
        "ლიბანი",
        "ლიბერია",
        "ლიბია",
        "ლიტვა",
        "ლიხტენშტაინი",
        "ლუქსემბურგი",
        "მადაგასკარი",
        "მავრიკი",
        "მავრიტანია",
        "მაიოტა",
        "მაკაო",
        "მაკედონია",
        "მალავი",
        "მალაიზია",
        "მალდივი",
        "მალი",
        "მალტა",
        "მაროკო",
        "მარშალის კუნძულები",
        "მარჯნის ზღვის კუნძულები",
        "მექსიკა",
        "მიანმარი",
        "მიკრონეზია",
        "მოზამბიკი",
        "მოლდოვა",
        "მონაკო",
        "მონსერატი",
        "მონღოლეთი",
        "ნამიბია",
        "ნაურუ",
        "ნეპალი",
        "ნიგერი",
        "ნიგერია",
        "ნიდერლანდი",
        "ნიდერლანდის ანტილები",
        "ნიკარაგუა",
        "ნიუე",
        "ნორვეგია",
        "ნორფოლკის კუნძული",
        "ომანი",
        "პაკისტანი",
        "პალაუ",
        "პალმირა (ატოლი)",
        "პანამა",
        "პაპუა-ახალი გვინეა",
        "პარაგვაი",
        "პერუ",
        "პიტკერნის კუნძულები",
        "პოლონეთი",
        "პორტუგალია",
        "პრინც-ედუარდის კუნძული",
        "პუერტო-რიკო",
        "ჟუან-დი-ნოვა",
        "რეიუნიონი",
        "რუანდა",
        "რუმინეთი",
        "რუსეთი",
        "საბერძნეთი",
        "სალვადორი",
        "სამოა",
        "სამხრეთ აფრიკის რესპუბლიკა",
        "სამხრეთი გეორგია და სამხრეთ სენდვიჩის კუნძულები",
        "სამხრეთი სუდანი",
        "სან-მარინო",
        "სან-ტომე და პრინსიპი",
        "საუდის არაბეთი",
        "საფრანგეთი",
        "საფრანგეთის გვიანა",
        "საფრანგეთის პოლინეზია",
        "საფრანგეთის სამხრეთული და ანტარქტიდული ტერიტორია",
        "საქართველო",
        "სეიშელის კუნძულები",
        "სენეგალი",
        "სენ-პიერი და მიკელონი",
        "სენტ-ვინსენტი და გრენადინები",
        "სენტ-კიტსი და ნევისი",
        "სენტ-ლუსია",
        "სერბეთი",
        "სეუტა",
        "სვაზილენდი",
        "სვალბარდი",
        "სიერა-ლეონე",
        "სინგაპური",
        "სირია",
        "სლოვაკეთი",
        "სლოვენია",
        "სოლომონის კუნძულები",
        "სომალი",
        "სომხეთი",
        "სუდანი",
        "სურინამი",
        "ტაივანი",
        "ტაილანდი",
        "ტანზანია",
        "ტაჯიკეთი",
        "ტერქსისა და კაიკოსის კუნძულები",
        "ტოგო",
        "ტოკელაუ",
        "ტონგა",
        "ტრინიდადი და ტობაგო",
        "ტუვალუ",
        "ტუნისი",
        "უგანდა",
        "უზბეკეთი",
        "უკრაინა",
        "უნგრეთი",
        "ურუგვაი",
        "ფარერის კუნძულები",
        "ფილიპინები",
        "ფინეთი",
        "ფიჯი",
        "ფოლკლენდის კუნძულები",
        "ქუვეითი",
        "ღაზის სექტორი",
        "ყაზახეთი",
        "ყირგიზეთი",
        "შვეიცარია",
        "შვედეთი",
        "შობის კუნძული",
        "შრი-ლანკა",
        "ჩადი",
        "ჩერნოგორია",
        "ჩეხეთი",
        "ჩეჩნეთის რესპუბლიკა იჩქერია",
        "ჩილე",
        "ჩინეთი",
        "ჩრდილოეთი მარიანას კუნძულები",
        "ცენტრალური აფრიკის რესპუბლიკა",
        "წმინდა ელენე, ამაღლება და ტრისტანი-და-კუნია",
        "წყნარი ოკეანის კუნძულები",
        "ხორვატია",
        "ჯერსი",
        "ჯიბუტი",
        "ჰაიტი",
        "ჰონდურასი",
        "ჰონკონგი",
        "ჰერდი და მაკდონალდის კუნძულები",
    )

    # Source: Tbilisi city directory
    # http://directory.ge/map/index.php?lang=eng
    street_titles = (
        "300 არაგველის",
        "8 მარტის",
        "აბაკელიას",
        "აბანოს",
        "აბასთუმანის",
        "აბაშელის",
        "აბაშის",
        "აბაშიძე გრიგოლის",
        "აბაშიძე დოდოს",
        "აბაშიძე ირაკლის",
        "აბაშიძე ჰეიდარის",
        "აბაშიძის",
        "აბდუშელიშვილი მალხაზის",
        "აბესაძე გიას",
        "აბზიანიძის",
        "აბო ტბილელის",
        "აბოვიანის",
        "აბუსერიძე-ტბელის",
        "აგარის",
        "აგლაძე რაფიელის",
        "ადიგენის",
        "ავთანდილის",
        "ავლაბრის",
        "ავლევის",
        "ათონელის",
        "აკეთის",
        "აკოფიანის",
        "აკურის",
        "ალადაშვილის",
        "ალაზნის",
        "ალგეთის",
        "ალექსიძე მერაბის",
        "ალვანის",
        "ალიხანიანის",
        "ალმასიანის",
        "ამაღლების",
        "ამბროლაურის",
        "ამირანაშვილი პეტრეს",
        "ამირეჯიბის",
        "ანაკლიის",
        "ანანურის",
        "ანდრონიკაშვილის",
        "ანდღულაძის",
        "ანტონ კატალიკოსის",
        "ანტონოვსკაიას",
        "ანჯაფარიძე ვერიკოს",
        "არაგვის",
        "არაგვისპირელი შიოს",
        "არალეთის",
        "არარატის",
        "არაყიშვილი დიმიტრის",
        "არბოს",
        "არბოშიკის",
        "არგვეთის",
        "არდაზიანის",
        "არდონის",
        "არეშიძის",
        "არველაძის",
        "ართვინის",
        "არმაზის",
        "არსენალის",
        "ასათიანი ლადოს",
        "ასკანის",
        "ასურეთის",
        "ასხინის",
        "ატენის",
        "აფანასიევის",
        "აფხაზეთის",
        "აწყურის",
        "აჭარის",
        "ახალარსენალის",
        "ახალდაბის",
        "ახალუბნის",
        "ახალქალაქის",
        "ახვლედიანი ელენეს",
        "ახვლედიანი გიორგის",
        "ახვლედიანის",
        "ახმეტელის",
        "ახმეტის",
        "ახოსპირელის",
        "ახტალის",
        "ახუთის",
        "ახუნდოვის",
        "აჯამეთის",
        "ბააზოვის",
        "ბაგინეთის",
        "ბადიაურის",
        "ბაზალეთის",
        "ბათუმის",
        "ბაკურიანის",
        "ბაკურციხის",
        "ბალადინის",
        "ბალანჩივაძე მელიტონის",
        "ბარათაშვილი ნოკოლოზის",
        "ბარათაშვილის",
        "ბარალეთის",
        "ბარამიძე ალექსანდრეს",
        "ბარისახოს",
        "ბარნოვის",
        "ბაქოს",
        "ბაქრაძე დავითის",
        "ბაქრაძე დიმიტრის",
        "ბაღდათის",
        "ბაღნარის",
        "ბახმაროს",
        "ბახტრიონის",
        "ბედიის",
        "ბევრეთის",
        "ბეთანიის",
        "ბეთლემის",
        "ბელიაშვილი აკაკის",
        "ბენაშვილის",
        "ბენდელიანი ჭიჭიკოს",
        "ბეჟანიშვილი ეკას",
        "ბერბუქის",
        "ბერიაშვილის",
        "ბერიკაშვილის",
        "ბერიტაშვილის",
        "ბერიძე ვუკოლის",
        "ბერძენიშვილის",
        "ბესიკის",
        "ბექა ოპიზარის",
        "ბეღლეთის",
        "ბზიფის",
        "ბიჭვინთის",
        "ბოგვის",
        "ბოდავის",
        "ბოდბის",
        "ბოლნისის",
        "ბორბალოს",
        "ბოროდინოს",
        "მ. ლებანიძის",
        "ბოტანიკურის",
        "ბოცვაძის",
        "ბოჭორიშვილის",
        "ბოჭორმის",
        "ბჟოლეთის",
        "ბროლოსანის",
        "ბროსეს",
        "ბუაჩიძე თენგიზის",
        "ბუდაპეშტის",
        "ბულაჩაურის",
        "ბურკიაშვილის",
        "ბურძგლას",
        "ბუღეულის",
        "ბუხაიძის",
        "გაბაშვილი ეკატერინეს",
        "გაგარინი იურის",
        "გალავნის",
        "გალაქტიონ ტაბიძის",
        "გალის",
        "გამრეკელის",
        "გამყრელიძის",
        "გამცემლიძე შოთას",
        "განთიადის",
        "გარე კახეთის",
        "გარეჯელი დავითის",
        "გარიყული მარიამის",
        "გაფრინდაულის",
        "გახოკიძე აკაკის",
        "გახოკიძის",
        "გეგუთის",
        "გედევანიშვილის",
        "გეზათის",
        "გელათის",
        "გერგეტის",
        "გვაზაურის",
        "გვეტაძე რაჟდენის",
        "გივიშვილის",
        "გიორგაძის",
        "გიორგი ბრწყინვალის",
        "გიორგი მერჩულეს",
        "გლინკას",
        "გოგაშენის",
        "გოგებაშვილის იაკობის",
        "გოგიბერიძის",
        "გოგოლაურის",
        "გოგოლის",
        "გოგჩის",
        "გოთუას",
        "გოკიელის",
        "გომარეთის",
        "გომბორის",
        "გომის",
        "გონაშვილი ჰამლეტის",
        "გორგასლის",
        "გორდის",
        "გორის",
        "გორკის",
        "გოცირიძის",
        "გოძიაშვილის",
        "გრანელი ტერენტის",
        "გრიბოედოვის",
        "გრიშაშვილის",
        "გროზნოს",
        "გრუზინსკი პეტრეს",
        "გუდამაყრის",
        "გუდარეხის",
        "გუდარის",
        "გუდაუთის",
        "გუდიაშვილი ლადოს",
        "გუთნის",
        "გულიას",
        "გულისაშვილის",
        "გულუა გიას",
        "გუმათის",
        "გუმათჰესის",
        "გუმბრის",
        "გუნიას",
        "გურგენიძის",
        "გურიელის",
        "გურიის",
        "გურჯაანის",
        "დაბახანას",
        "დადიანი შალვას",
        "დადიანი ცოტნეს",
        "დაისის",
        "ლ. ელიავას",
        "დარკვეთის",
        "დგებუაძის",
        "დედოფლისწყაროს",
        "დეკაბრისტების",
        "დელისის",
        "დეპოს",
        "დვალის",
        "დვირის",
        "დიდგორის",
        "დიდხევის",
        "დიდი ხეივნის",
        "დიდი ჯიხაიშის",
        "დ. ყიფიანის",
        "დიმიტრი თავდადებულის",
        "დირსიჭალას",
        "დიუმა ალექსანდრეს",
        "დმანისის",
        "დობროლიუბოვის",
        "დოდაშვილი სოლომონის",
        "დოესის",
        "დოლიძე გოგის",
        "დოლიძის",
        "დოქის",
        "დოღუმბარის",
        "დუტუ მეგრელის",
        "დუშეთის",
        "ედისის",
        "ევდოშვილის",
        "ეკალაძის",
        "ელდარის",
        "ენგურის",
        "ენგურჰესის",
        "ენისელის",
        "ენუქიძის",
        "ერევნის",
        "ერისთავი თორნიკეს",
        "ერისთავი კონსტანტინეს",
        "ერისთავ-ხოშტარიას",
        "ერწოს",
        "ესენინის",
        "სანდრო ეულის",
        "ეფრემ მცირის",
        "ექიმის",
        "ვაზიანის",
        "ვაზისუბნის",
        "ვაკელი იონას",
        "ვანის",
        "ვარდევანის",
        "ვარდისუბნის",
        "ვართაგავას",
        "რომის",
        "ვასაძის",
        "ვაშლოვანის",
        "ვახტანგ VI–ის",
        "ვეზიროვის",
        "ვეკუა ვოვას",
        "ვერცხლის",
        "ვერჰარნის",
        "ვეძათხევის",
        "ვეძინის",
        "ვირსალაძის",
        "ვორონინის",
        "საარბრჯუკენის",
        "ზაზიშვილი გიგოს",
        "ზალდასტანიშვილის",
        "ზანდუკელი მიხეილის",
        "ზარზმის",
        "ზაქარიაძე სერგოს",
        "ზედაზნის",
        "ზედამზის",
        "ზედაუბნის",
        "ზეინკლის",
        "ზეკარის",
        "ზემო ვაკის",
        "ზემო ვეძისის",
        "ზესტაფონის",
        "ზვარეთის",
        "ზიარის",
        "ზიგზაგის",
        "ზინდისის",
        "ზიჩი მიხაის",
        "ზოვრეთის",
        "ზუბალაშვილების",
        "ზუგდიდის",
        "ზურაბიშვილი ავლიპის",
        "თაბუკაშვილი რეზოს",
        "თავაძე ფერდინანდის",
        "თამარაშენის",
        "თამარაშვილი მიხეილის",
        "გ. სვანიძის",
        "თარხნიშვილის",
        "თაქთაქიშვილის",
        "თაყაიშვილი სესილიას",
        "თევდორე მღვდლის",
        "თეთნულდის",
        "თეთრიწყაროს",
        "თეკლათის",
        "თელავის",
        "ხახანაშვილის",
        "თელეთის",
        "თერგის",
        "თეძმის",
        "თვალჭრელიძის",
        "თიანეთის",
        "თმოგველის",
        "თმოგვის",
        "თოდრიას",
        "თოიძის",
        "თონეს",
        "თორაძის",
        "თოფურიას",
        "თრიალეთის",
        "თუმანიანის",
        "თხინვალის",
        "იალბუზის",
        "იამანიძე შოთას",
        "იაშვილი პაოლოს",
        "იბრაჰიმ ისპაჰანელის",
        "იდუმალას",
        "იეთიმ გურჯის",
        "იერუსალიმის",
        "ივერიის",
        "ივლეთის",
        "იზაშვილის",
        "ილორის",
        "ილურიძე კონსტანტინეს",
        "იმედაშვილი გაიოზის",
        "იმერეთის",
        "ინანიშვილი რამაზის",
        "ინაშვილის",
        "ინგოროყვა პავლეს",
        "ინტერნატის",
        "იორის",
        "იოსებიძის",
        "იოსელიანის",
        "იპოლიტე-ივანოვის",
        "ირბაქი ნიკიფორეს",
        "ირგვლივის",
        "ისაკიანის",
        "ისნის",
        "იფნის",
        "იყალთოს",
        "კავთისხევის",
        "კავსაძის",
        "კაიშაურის",
        "კაკაბაძე პოლიკარპეს",
        "კაკაბაძეების",
        "კაკლიანის",
        "კოტე ხიმშიაშვილის",
        "კალატოზის",
        "კალიუჟნის",
        "კალოუბნის",
        "კანდელაკის",
        "კანდელაკის",
        "კანკავას",
        "კაპანაძის",
        "კარალეთის",
        "კარგარეთელის",
        "კასპის",
        "კაჭრეთის",
        "კახიანის",
        "კედია სპირიდონის",
        "კეკელიძე კორნელის",
        "კელაპტრიშვილი ომარის",
        "კერესელიძე არჩილის",
        "კერესელიძის",
        "კეცხოველი ნიკოს",
        "კვალეთის",
        "კვალის",
        "კვანტალიანის",
        "კვერნაულის",
        "კვესეთის",
        "კიევის",
        "კიკეთის",
        "კიკვიძის",
        "კისისხევის",
        "კიშინიოვის",
        "კლდეკარის",
        "კლდიაშვილის",
        "კნოლევის",
        "კობახიძის",
        "კობერიძის",
        "კოდალოს",
        "კოდორის",
        "კოკინაკის",
        "კოლმეურნეობის ველის",
        "კოლხეთის",
        "კომუნის",
        "კონდოლის",
        "კონსტიტუციის",
        "კოფცოვის",
        "კოსტავას",
        "კოტეტიშვილი ვახტანგის",
        "კოშკოვანის",
        "კოხრეიძის",
        "კოჯრის",
        "ჯ. კახიძის",
        "კრწანისის",
        "კუმისის",
        "კუპრაძის",
        "კურნატოვსკის",
        "კურსების",
        "კურსკის",
        "კუფტინის",
        "ლაგოდეხის",
        "ლაზოს",
        "ლაითურის",
        "ლაილაშის",
        "ლალიონის",
        "ლამის",
        "ლამისყანის",
        "ლანჩხუთის",
        "ლარეხის",
        "ლარსის",
        "ლაღიძე მიტროფანეს",
        "ლაღიძე რევაზის",
        "ლებარდეს",
        "ლეკიშვილის",
        "ლენტეხის",
        "ლეონიძე გიორგის",
        "ლეჟავას",
        "ლერმონტოვის",
        "ლერწმის",
        "ლესელიძის",
        "ლესია უკრაინკას",
        "ლეჩხუმის",
        "ლიახვის",
        "ლიბანის",
        "ლიკანის",
        "ლისაშვილის",
        "ლიუბოვსკის",
        "ლიხაურის",
        "ლიხის",
        "ლომაურის",
        "ლომთათიძის",
        "ლომონოსოვის",
        "ლორთქიფანიძე გრიგოლის",
        "ლორთქიფანიძის",
        "ლოჭინის",
        "ლუბლიანას",
        "ლუსიანინის",
        "მაზნიაშვილის",
        "მათიაშვილის",
        "მაიაკოვსკის",
        "მამასახლისოვის",
        "მამკოდის",
        "მამკოდის",
        "მამრაძის",
        "მანაგაძე ალეხსანდეს",
        "მანავის",
        "მანგლისის",
        "მანიჯაშვილი კახას",
        "მანჯგალაძე ეროსის",
        "მარაბდის",
        "მარგიანი რევაზის",
        "მარელისის",
        "მარი ნიკოს",
        "მარიჯანის",
        "მარტვილის",
        "მარტყოფის",
        "მარუაშვილი გიორგის",
        "მარუხის გმირების",
        "მარჯანიშვილი კოტეს",
        "მარჯანიშვილი კოტეს",
        "მაღალაშვილის",
        "მაღაროს",
        "მაჩაბელი ივანეს",
        "მაჩხაანის",
        "მაცესტის",
        "მაჭრის",
        "მახათას",
        "მახინჯაურის",
        "მგალობლიშვილის",
        "მებაღიშვილის",
        "მეგობრობის",
        "მეგრელაძის",
        "მეველეს",
        "მელაანის",
        "მელიქიშვილის",
        "მესხეთის",
        "მესხიას",
        "მესხიშვილი ალექსის",
        "მესხიშვილის",
        "მეტეხის",
        "მეუნარგიას",
        "მექანიზაციის",
        "მეჯვრისხევის",
        "მთავარანგელოზის",
        "მთაწმინდის",
        "მთისძირის",
        "მიმინოშვილი რომანის",
        "მინდელაურის",
        "მინდელის",
        "მირზა მეფის",
        "მირზაანის",
        "მიროტაძის",
        "მიტინგის",
        "მიქატაძის",
        "მიქატაძის",
        "მიქელაძე ევგენის",
        "მიქელაძის",
        "მიშველაძე არჩილის",
        "მიჩურინის",
        "მიცკევიჩის",
        "მნათობის",
        "მოლითის",
        "მოლოკოვის",
        "მორეტის",
        "მოსაშვილის",
        "მოსე ხონელის",
        "მოსიძე ვახტანგის",
        "მოსტკოვის",
        "მოსულიშვილის",
        "მრევლიშვილის",
        "მტკვრის",
        "მუკუზანის",
        "მუსხელიშვილის",
        "მუხაძის",
        "მუხაძის",
        "მუხრანის",
        "მშველიძის",
        "მცხეთის",
        "ნაბახტაურის",
        "ნაგომარის",
        "ნადიკვარის",
        "ნადირაძე კოლაუს",
        "ნავთლუღის",
        "ნათაძის",
        "ნაკადულის",
        "ნიშნიანიძის",
        "ნანეიშვილი ვიქტორის",
        "ნანეიშვილი ვლადიმერის",
        "ნარგიზის",
        "ნასაკირალის",
        "ნასიძე სულხანის",
        "ნაქალაქევის",
        "ნაქერალას",
        "ნიაბის",
        "ნიაღვრის",
        "ნიზამის",
        "ნიკოლაძე ნიკოს",
        "ნინიძის",
        "ნიორაძის",
        "ნოვოროსისკის",
        "ნონეშვილი იოსების",
        "ნოსირის",
        "ნოსტეს",
        "ნუცუბიძის",
        "ობსერვატორიის",
        "ოდესის",
        "ონიაშვილის",
        "ონის",
        "ოჟიოს",
        "ორბეთის",
        "ორბელების",
        "ორთაჭალის",
        "ორპირის",
        "ორხევის",
        "ოსეთის",
        "ოსიაურის",
        "ოფრეთის",
        "ოქრომჭედლების",
        "ოქროყანის",
        "ოჩამჩირის",
        "ოცხელების",
        "ოძელაშვილის",
        "ოძისის",
        "პაიჭაძის",
        "პალიასტომის",
        "პანკისის",
        "პასტერის",
        "პატარიძის",
        "პატარძეულის",
        "პეტეფი შანდორის",
        "პეტრე იბერის",
        "პეტრიაშვილის",
        "პეტრიწის",
        "პიატიგორსკის",
        "პიონერის",
        "პისარევის",
        "პლატონის",
        "პუშკინი ალექსანდრეს",
        "ჟველაურის",
        "ჟინვალის",
        "ჟონეთის",
        "ჟორესის",
        "ჟღენტის",
        "რადიანი შალვას",
        "რაზიკაშვილის",
        "რაზმაძის",
        "რატევანის",
        "რატილის",
        "რაჭის",
        "რევოლუცის",
        "რთველაძის",
        "რიონის",
        "რიონჰესის",
        "რიწის",
        "რკინიგზის",
        "რკინის",
        "როდენის",
        "როსტოვის",
        "როსტომაშვილის",
        "რუისპირის",
        "რუსთაველის",
        "რჩეულიშვილის",
        "საადის",
        "სააკაძე პაატას",
        "სააკაძის",
        "საბადურის",
        "საბანისძის",
        "საბაშვილის",
        "საგარეჯოს",
        "საგურამოს",
        "სადმელის",
        "სავანელის",
        "სათემოს",
        "საიათნოვას",
        "საირმის",
        "სალამის",
        "სალხინოს",
        "სამამულო ომის გმირების",
        "სამგორის",
        "სამტრედიის",
        "სამურზაყანოს",
        "სამურის",
        "სამღებროს",
        "სამღერეთის",
        "სამშვილდეს",
        "სანავარდოს",
        "სანკტ-პეტერბურგის",
        "სარაჯიშვილი დავითის",
        "სარაჯიშვილი პეტრეს",
        "სართანიას",
        "სართიჭალის",
        "სარკინეთის",
        "საქანელას",
        "საქარის",
        "საყვირის",
        "საჩხერის",
        "საცხენისის",
        "საჭილაოს",
        "სახოკიას",
        "სევანის",
        "სენაკის",
        "სვანეთის",
        "გუდაურის",
        "სვირის",
        "სიონის",
        "სიღნაღის",
        "სიხარულიძის",
        "სკოლის",
        "სომხეთის",
        "სოხუმის",
        "სოღანლუღის",
        "სპანდარიანის",
        "სპარტაკის",
        "სტამბის",
        "სტანისლავსკის",
        "სტურუას",
        "სუვოროვის",
        "სულიაშვილის",
        "სულხანიშვილის",
        "სულხან-საბას",
        "სუმბატაშვილ-იუჟინსკის",
        "სუნდუკიანის",
        "სურამის",
        "სურგულაძის",
        "სხვიტორის",
        "სხირტლაძის",
        "სხულუხიას",
        "ტაბახმელას",
        "ტაბიძე ტიციანის",
        "ტანძიის",
        "ტარიელის",
        "ტატიშვილი ერეკლეს",
        "ტატიშვილის",
        "ტაშირის",
        "ტაშკენტის",
        "ტელეგრაფის",
        "ტეტელაშვილის",
        "ტეხურის",
        "ტვიშის",
        "ტიბაანის",
        "ტირიფონის",
        "ტიულენევის",
        "ტიხონოვის",
        "ტოლენჯის",
        "ტოლსტოის",
        "ტოლსტონოგოვის",
        "ტრანსპორტის",
        "ტრაქტორის",
        "ტრიკოტაჟის",
        "ტურგენევის",
        "ტუსკიას",
        "ტყავის",
        "ტყეკულტურის",
        "ტყვარჩელის",
        "ტყვიავის",
        "ტყიბულის",
        "ტყის",
        "უბილავას",
        "უზნაძე დიმიტრის",
        "უზნაძის",
        "უიარაღოს",
        "უკლება კირილეს",
        "უმიკაშვილის",
        "უნივერსიტეტის",
        "ურბნისის",
        "ურეკის",
        "ურიდიას",
        "ურიცკის",
        "უფლისციხის",
        "უშაკოვის",
        "უჩანეიშვილი ირაკლის",
        "უწერის",
        "უჯარმის",
        "ფაბრიკის",
        "ფალიაშვილის",
        "ფანასკერტელ-ციციშვილის",
        "ფანჯიკიძის",
        "ფარავნის",
        "ფასანაურის",
        "ფაღავა ირაკლის",
        "ფერისცვალების",
        "ფიზკულტურის",
        "ფილიას",
        "ფირდოუსის",
        "ფიროსმანის",
        "ფიფიას",
        "ფოთის",
        "ფოსტის",
        "ფოცხვერაშვილის",
        "ფოცხიაშვილი მორისის",
        "ფურცელაძის",
        "ფშავის",
        "ქავთარაძის",
        "ქარელის",
        "ქართველიშვილი ლევანის",
        "ქართლის",
        "ქებურიას",
        "ქედის",
        "ქერჩის",
        "ქვალონის",
        "ქვიშხეთის",
        "ქიაჩელის",
        "ქიზიყის",
        "ქინქლაძე ოთარის",
        "ქინძმარაულის",
        "ქიქოძე გერონტის",
        "ქობულაძის",
        "ქობულეთის",
        "ქსნის",
        "ქსოვრელის",
        "ქუთათელაძის",
        "ქუთათელაძე აპოლონის",
        "ქუთაისის",
        "ქუმსიაშვილის",
        "ქურდიანი არჩილის",
        "ქურდიანი ზაქარიას",
        "ქურხულის",
        "ქუჩიშვილის",
        "ღამბაშიძის",
        "ღრმაღელეს",
        "ღუდუშაური ოთარის",
        "ყავლაშვილი შოთას",
        "ყარყარაშვილის",
        "ყვარელის",
        "ყირიმის",
        "ყიფიანის",
        "ყიფშიძის",
        "ყუშიტაშვილის",
        "შავგულიძის",
        "შავთელის",
        "შავი ზღვის",
        "შავიშვილის",
        "შავნაბადას",
        "შავსოფელის",
        "შანიძე აკაკის",
        "შანშიაშვილის",
        "შარაშიძის",
        "შარდენის",
        "შარტავა ჟიულის",
        "შატბერაშვილის",
        "შატილის",
        "შაქრიანის",
        "შევჩენკო ტარასის",
        "შენგელაიას",
        "შერვაშიძის",
        "შილდის",
        "შინდისის",
        "შიო მღვიმელის",
        "შირაქის",
        "შოვის",
        "შორაპნის",
        "შროშის",
        "შუამთის",
        "შურდულის",
        "შხეფის",
        "ჩაიკოვსკის",
        "ჩაილურის",
        "ჩაისუბნის",
        "ჩანჩიბაძის",
        "ჩარგლის",
        "ჩარხის",
        "ჩაქვის",
        "ჩაჩავას",
        "ჩახრუხაძის",
        "ჩერნიშევსკის",
        "ჩერქეზიშვილის",
        "ჩეჩელაშვილის",
        "ჩეხოვის",
        "ჩიკვანიას",
        "ჩიტაიას",
        "ჩიტაძის",
        "ჩიქობავა არნოლდის",
        "ჩიქოვანის",
        "ჩკალოვის",
        "ჩოლოყაშვილი ქაიხოსროს",
        "ჩოჩუას",
        "ჩოხატაურის",
        "ჩოხელის",
        "ჩუბინაშვილი გიორგის",
        "ჩუბინიძის",
        "ჩხიკვაძის",
        "ცაბაძე გიორგის",
        "ცაგარელი არჩილის",
        "ცაგერის",
        "ცაიშის",
        "ცემის",
        "ციმაკურიძის",
        "ცინცაძე კალისტრატეს",
        "ცისარტკელას",
        "ცისკრის",
        "ციხისძირის",
        "ცოდნისკარის",
        "ცურტაველი იაკობის",
        "ცუცქირიძის",
        "ცხემის",
        "ცხვედაძის",
        "ცხრა აპრილის",
        "ცხრა ძმის",
        "ძეგამის",
        "ძევერის",
        "ძმობის",
        "ძოწენიძის",
        "წავკისის",
        "წალენჯიხის",
        "წალკის",
        "წაღვერის",
        "წერეთლის",
        "წერნაკის",
        "წერონისის",
        "წიკლაურის",
        "წინამძღვრიშვილის",
        "წინამძღვრიშვილის",
        "წინანაურის",
        "წინანდლის",
        "წინაუბნის",
        "წიწამურის",
        "წმ. ნიკოლოზის",
        "წნორისწყლის",
        "წრომის",
        "წულაძის",
        "წულუკიძის",
        "წურწუმიას",
        "წუწუნავას",
        "წუწხვატის",
        "წყალსადენის",
        "წყალტუბოს",
        "წყაროს",
        "ჭაბუკიანი ვახტანგის",
        "ჭავჭავაძე ზურაბის",
        "ჭავჭავაძე ალექსანდრეს",
        "ჭალადიდის",
        "ჭანტურია გიას",
        "ჭიათურის",
        "ჭიაურელი მიხეილის",
        "ჭიჭინაძე ზაქარიას",
        "ჭოველიძე თამარის",
        "ჭონქაძე დანიელის",
        "ჭოპორტის",
        "ჭოროხის",
        "ჭრებალოს",
        "ჭრელაშვილის",
        "ხაბეიშვილის",
        "ხაზინის",
        "ხანძთელი გრიგოლის",
        "ხარაბაძის",
        "ხარაგაულის",
        "ხარფუხის",
        "ხაჩატურიანის",
        "ხევის",
        "ხევისუბნის",
        "ხევსურეთის",
        "ხევძმარის",
        "ხეთაგუროვის",
        "ხერგიანის",
        "ხერთვისის",
        "ხერხეულიძეების",
        "ხეჩუაშვილის",
        "ხვამლის",
        "ხვანჭკარის",
        "ხვედელიანის",
        "ხვინგიას",
        "ხვიჩია იპოლიტეს",
        "ხიდის",
        "ხიდისთავის",
        "ხივინის",
        "ხიმშიაშვილის",
        "ხმელნიცკის",
        "ხოდაშენის",
        "ხომლელის",
        "ხონის",
        "ხორავა აკაკის",
        "ხორნაბუჯის",
        "ხოშარაულის",
        "ხრამჰესის",
        "ხრესილის",
        "ხუდადოვის",
        "ჯაბაურის",
        "ჯაბიძის",
        "ჯავახეთის",
        "ჯავახიშვილი ივანეს",
        "ჯავახიშვილი მიხეილის",
        "ჯავის",
        "ჯამბულის",
        "ჯანაშვილის",
        "ჯანაშიას",
        "ჯანჯღავას",
        "ჯვარედინის",
        "პოლიტკოვსკაიას",
        "ჯიქიას",
        "ჯორბენაძის",
        "ჯორჯაძის",
        "ჰოსპიტალის",
    )

    # Source: List of cities and towns in Georgia (Wikipedia)
    # https://en.wikipedia.org/wiki/List_of_cities_and_towns_in_Georgia_(country)
    city_names = (
        "აბაშა",
        "ამბროლაური",
        "ახალი ათონი",
        "ახალქალაქი",
        "ახალციხე",
        "ახმეტა",
        "ბათუმი",
        "ბაღდათი",
        "ბოლნისი",
        "ბორჯომი",
        "გაგრა",
        "გალი",
        "გარდაბანი",
        "გორი",
        "გუდაუთა",
        "გურჯაანი",
        "დედოფლისწყარო",
        "დმანისი",
        "დუშეთი",
        "ვალე",
        "ვანი",
        "ზესტაფონი",
        "ზუგდიდი",
        "თბილისი",
        "თეთრიწყარო",
        "თელავი",
        "თერჯოლა",
        "კასპი",
        "ლაგოდეხი",
        "ლანჩხუთი",
        "მარნეული",
        "მარტვილი",
        "მცხეთა",
        "ნინოწმინდა",
        "ოზურგეთი",
        "ონი",
        "ოჩამჩირე",
        "რუსთავი",
        "საგარეჯო",
        "სამტრედია",
        "საჩხერე",
        "სენაკი",
        "სიღნაღი",
        "სოხუმი",
        "ტყვარჩელი",
        "ტყიბული",
        "ფოთი",
        "ქარელი",
        "ქობულეთი",
        "ქუთაისი",
        "ყვარელი",
        "ცაგერი",
        "ცხინვალი",
        "წალენჯიხა",
        "წალკა",
        "წნორი",
        "წყალტუბო",
        "ჭიათურა",
        "ხაშური",
        "ხობი",
        "ხონი",
        "ჯვარი",
    )

    def street_title(self) -> str:
        return self.random_element(self.street_titles)

    def city_name(self) -> str:
        return self.random_element(self.city_names)



from ..ar_AA import Provider as ArabicPersonProvider


class Provider(ArabicPersonProvider):
    last_names = (
        "حجار",
        "آل الشيخ",
        "الحجار",
        "حنبولي",
        "آل سعود",
        "آل علي",
        "آل جعفر",
        "أبا الخيل",
        "المهنا",
        "مهنا",
        "بن لادن",
        "كانو",
        "الجفالي",
        "فصيل",
        "آل رفيع",
        "آل بن لافي",
        "آل العسكري",
        "آل بن ظافر",
        "آل عواض",
        "المشاولة",
        "آل مقطة",
        "آل عايض",
        "آل معيض",
        "آل حسين",
        "المغاولة",
        "آل خضير",
        "آل صفوان",
        "آل محمد بن علي بن جماز",
        "آل عطفة",
        "آل قصير",
        "آل سلطان",
        "العليان",
        "الشايع",
        "أبو داوود",
        "الدباغ",
        "العجلان",
        "الراشد",
        "المهيدب",
        "العقيل",
        "شربتلي",
        "الخرافي",
        "أبو داوود",
        "الجابر",
        "بقشان",
        "الحكير",
    )



from .. import Provider as InternetProvider


class Provider(InternetProvider):

    free_email_domains = (
        "gmail.com",
        "yahoo.com",
        "hotmail.com",
        "inspire.net.nz",
        "xtra.co.nz",
    )

    tlds = (
        "nz",
        "co.nz",
        "org.nz",
        "kiwi",
        "kiwi.nz",
        "geek.nz",
        "net.nz",
        "school.nz",
        "ac.nz",
        "maori.nz",
    )



from .. import Provider as DateTimeProvider


class Provider(DateTimeProvider):

    DAY_NAMES = {
        "0": "domenica",
        "1": "lunedì",
        "2": "martedì",
        "3": "mercoledì",
        "4": "giovedì",
        "5": "venerdì",
        "6": "sabato",
    }

    MONTH_NAMES = {
        "01": "gennaio",
        "02": "febbraio",
        "03": "marzo",
        "04": "aprile",
        "05": "maggio",
        "06": "giugno",
        "07": "luglio",
        "08": "agosto",
        "09": "settembre",
        "10": "ottobre",
        "11": "novembre",
        "12": "dicembre",
    }

    def day_of_week(self):
        day = self.date("%w")
        return self.DAY_NAMES[day]

    def month_name(self):
        month = self.month()
        return self.MONTH_NAMES[month]



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = ["{{first_name}} {{last_name}}"]

    first_names_male = [
        "Franc",
        "Janez",
        "Anton",
        "Ivan",
        "Jožef",
        "Andrej",
        "Marko",
        "Marjan",
        "Peter",
        "Milan",
        "Stanislav",
        "Matej",
        "Tomaž",
        "Branko",
        "Bojan",
        "Robert",
        "Boštjan",
        "Matjaž",
        "Gregor",
        "Luka",
        "Martin",
        "Rok",
        "Boris",
        "Dušan",
        "Igor",
        "Miha",
        "Dejan",
        "David",
        "Uroš",
        "Simon",
        "Jure",
        "Blaž",
        "Štefan",
        "Jan",
        "Drago",
        "Darko",
        "Klemen",
        "Nejc",
        "Žiga",
        "Jernej",
        "Miran",
        "Aleksander",
        "Roman",
        "Vladimir",
        "Matic",
        "Tadej",
        "Srečko",
        "Slavko",
        "Mirko",
        "Janko",
        "Žan",
        "Miroslav",
        "Borut",
        "Alojzij",
        "Damjan",
        "Stanko",
        "Aljaž",
        "Anže",
        "Danijel",
        "Mihael",
        "Matija",
        "Jaka",
        "Marijan",
        "Rudolf",
        "Alen",
        "Jakob",
        "Viktor",
        "Domen",
        "Sašo",
        "Iztok",
        "Goran",
        "Tilen",
        "Pavel",
        "Zvonko",
        "Edvard",
        "Zdravko",
        "Danilo",
        "Matevž",
        "Rajko",
        "Ludvik",
        "Zlatko",
        "Frančišek",
        "Bogdan",
        "Gorazd",
        "Samo",
        "Leon",
        "Dragan",
        "Emil",
        "Josip",
        "Nik",
        "Ciril",
        "Sandi",
        "Benjamin",
        "Vid",
        "Albin",
        "Franci",
        "Sebastjan",
        "Silvo",
        "Leopold",
        "Kristjan",
        "Tim",
        "Filip",
        "Damijan",
        "Erik",
        "Viljem",
        "Vincenc",
        "Željko",
        "Damir",
        "Aljoša",
        "Karel",
        "Daniel",
        "Dominik",
        "Miloš",
        "Stojan",
        "Franjo",
        "Valentin",
        "Davorin",
        "Maks",
        "Timotej",
        "Ladislav",
        "Niko",
        "Mark",
        "Nikola",
        "Bogomir",
        "Saša",
        "Vlado",
        "Karl",
        "Zdenko",
        "Grega",
        "Stjepan",
        "Davor",
        "Kristijan",
        "Ernest",
        "Maksimiljan",
        "Avgust",
        "Sebastijan",
        "Aleksandar",
        "Lovro",
        "Ivo",
        "Rado",
        "Tine",
        "Adolf",
        "Gal",
        "Valter",
        "Elvis",
        "Jasmin",
        "Ervin",
        "Jani",
        "Izidor",
        "Nenad",
        "Anej",
        "Petar",
        "Maj",
        "Metod",
        "Albert",
        "Bruno",
        "Radovan",
        "Nikolaj",
        "Feliks",
        "Karol",
        "Bernard",
        "Joško",
        "Rafael",
        "Edin",
        "Aleks",
        "Cvetko",
        "Rudi",
        "Miro",
        "Hasan",
        "Slobodan",
        "Mirsad",
    ]

    first_names_female = [
        "Marija",
        "Ana",
        "Irena",
        "Maja",
        "Mojca",
        "Jožefa",
        "Mateja",
        "Nataša",
        "Jožica",
        "Barbara",
        "Ivana",
        "Andreja",
        "Nina",
        "Petra",
        "Katja",
        "Sonja",
        "Milena",
        "Katarina",
        "Tatjana",
        "Anja",
        "Alenka",
        "Tanja",
        "Martina",
        "Vesna",
        "Tina",
        "Angela",
        "Urška",
        "Antonija",
        "Anica",
        "Kristina",
        "Dragica",
        "Nada",
        "Olga",
        "Špela",
        "Darja",
        "Marjeta",
        "Tjaša",
        "Eva",
        "Ljudmila",
        "Simona",
        "Vida",
        "Sara",
        "Zdenka",
        "Alojzija",
        "Lidija",
        "Suzana",
        "Marta",
        "Nika",
        "Sabina",
        "Silva",
        "Veronika",
        "Štefanija",
        "Stanislava",
        "Darinka",
        "Karmen",
        "Neža",
        "Brigita",
        "Anita",
        "Aleksandra",
        "Pavla",
        "Cvetka",
        "Metka",
        "Nevenka",
        "Monika",
        "Rozalija",
        "Natalija",
        "Slavica",
        "Marjana",
        "Branka",
        "Jasmina",
        "Vera",
        "Ema",
        "Saša",
        "Maša",
        "Lara",
        "Lucija",
        "Tamara",
        "Bernarda",
        "Danijela",
        "Klavdija",
        "Erika",
        "Romana",
        "Mira",
        "Jasna",
        "Klara",
        "Kaja",
        "Jelka",
        "Polona",
        "Julijana",
        "Valerija",
        "Sandra",
        "Matilda",
        "Tadeja",
        "Valentina",
        "Mihaela",
        "Amalija",
        "Albina",
        "Breda",
        "Karolina",
        "Sanja",
        "Teja",
        "Ines",
        "Zofija",
        "Ksenija",
        "Laura",
        "Cecilija",
        "Patricija",
        "Magdalena",
        "Manca",
        "Viktorija",
        "Maruša",
        "Vanja",
        "Vlasta",
        "Justina",
        "Nuša",
        "Emilija",
        "Melita",
        "Ljubica",
        "Lana",
        "Marica",
        "Gordana",
        "Marinka",
        "Polonca",
        "Nadja",
        "Milka",
        "Živa",
        "Urša",
        "Damjana",
        "Hana",
        "Tea",
        "Marijana",
        "Julija",
        "Ajda",
        "Nastja",
        "Milica",
        "Alja",
        "Štefka",
        "Slavka",
        "Jerneja",
        "Nives",
        "Dušanka",
        "Andrejka",
        "Irma",
        "Pia",
        "Jelena",
        "Marjanca",
        "Miroslava",
        "Lilijana",
        "Stanka",
        "Mirjam",
        "Neja",
        "Jolanda",
        "Zora",
        "Zvonka",
        "Hermina",
        "Rebeka",
        "Hedvika",
        "Blanka",
        "Larisa",
        "Erna",
        "Anka",
        "Roza",
        "Liljana",
        "Magda",
        "Daniela",
        "Jerica",
        "Taja",
        "Iris",
        "Adrijana",
        "Jadranka",
    ]

    first_names = first_names_female + first_names_male
    last_names = [
        "Novak",
        "Horvat",
        "Krajnc",
        "Kovačič",
        "Zupančič",
        "Kovač",
        "Potočnik",
        "Mlakar",
        "Vidmar",
        "Kos",
        "Golob",
        "Turk",
        "Božič",
        "Zupan",
        "Korošec",
        "Bizjak",
        "Hribar",
        "Kotnik",
        "Rozman",
        "Petek",
        "petek",
        "Kastelic",
        "Kolar",
        "Hočevar",
        "Žagar",
        "žagar",
        "Košir",
        "Koren",
        "Klemenčič",
        "Zajc",
        "Medved",
        "Knez",
        "Zupanc",
        "Pirc",
        "Hrovat",
        "Pavlič",
        "Kuhar",
        "kuhar",
        "Lah",
        "Zorko",
        "Sever",
        "Majcen",
        "Jerman",
        "Babič",
        "Tomažič",
        "Erjavec",
        "Jereb",
        "Kranjc",
        "Rupnik",
        "Perko",
        "Lesjak",
        "Breznik",
        "Pečnik",
        "Pavlin",
        "Dolenc",
        "Vidic",
        "Furlan",
        "Logar",
        "Tomšič",
        "Jenko",
        "Janežič",
        "ribič",
        "Žnidaršič",
        "Černe",
        "Maček",
        "Lešnik",
        "Fras",
        "Marolt",
        "Jelen",
        "Gregorič",
        "Blatnik",
        "Pintar",
        "Mihelič",
        "Kokalj",
        "Bezjak",
        "Leban",
        "Cerar",
        "Čeh",
        "čeh",
        "Jug",
        "Vidovič",
        "Rus",
        "Kobal",
        "Primožič",
        "Kocjančič",
        "Dolinar",
        "Lazar",
        "Kolenc",
        "Nemec",
        "Kolarič",
        "Lavrič",
        "Kodrič",
        "Kosi",
        "Mrak",
        "Debeljak",
        "Tavčar",
        "Žižek",
        "Krivec",
        "Zver",
        "Likar",
        "Žibert",
        "Jarc",
        "Vodopivec",
        "Kramberger",
        "Miklavčič",
        "Skok",
        "Toplak",
        "Petrovič",
        "Hribernik",
        "Leskovar",
        "Stopar",
        "Simonič",
        "Blažič",
        "Eržen",
        "Sitar",
        "Gorenc",
        "Železnik",
        "Šinkovec",
        "Jamnik",
        "Javornik",
        "Bukovec",
        "Hozjan",
        "Ramšak",
        "Filipič",
        "Kočevar",
        "Demšar",
        "Volk",
        "volk",
        "Gomboc",
        "Čuk",
        "Ilić",
        "Kokol",
        "Bregar",
        "Sušnik",
        "Pintarič",
        "Gorjup",
        "Jovanović",
        "Mavrič",
        "Kramar",
        "Lebar",
        "Rutar",
        "Koželj",
        "Popović",
        "Rajh",
        "Hodžić",
        "Rožman",
        "Resnik",
        "Šmid",
        "Kumer",
        "Godec",
        "Bergant",
        "Pogačnik",
        "Zemljič",
        "Hafner",
        "Tratnik",
        "Rožič",
        "Cvetko",
        "Ambrožič",
        "Bevc",
        "Mlinarič",
        "Mlinar",
        "Jerič",
        "Kalan",
        "Markovič",
        "Šuštar",
        "Bajc",
        "Kaučič",
        "Dolinšek",
        "Zalokar",
        "Pirnat",
        "Zorman",
        "Zakrajšek",
        "Štrukelj",
    ]



from ..ar_AA import Provider as ArabicPersonProvider


class Provider(ArabicPersonProvider):
    last_names = (
        "خوري",
        "شاهين",
        "البرغوثي",
        "الحسيني",
        "الزيدانية",
        "جرار",
        "السكاكيني",
        "طوقان",
        "نسيبة",
        "النشاشيبي",
        "الخازن",
        "ترابين",
        "دغمش",
        "دلاشة",
        "الزيتاوي",
        "صليبا",
        "التركمان",
        "الإغباري",
        "كسواني",
        "جزار",
        "أبو اسنينة",
        "التميمي",
        "الجنيدي",
        "بدر",
        "أبو شقدم",
        "أبو غليون",
        "أبو قمر",
        "الأدغم",
        "حوسة",
        "الصالحي",
        "حمامي",
        "هاشم",
        "الحنبلي",
        "أستيتية",
        "مرمش",
        "قرادة",
        "فطاير",
        "الخماش",
        "الخياط",
        "النعنيش",
        "مهيار",
        "أبو شلبك",
    )



import math
import string
import sys
import warnings

from decimal import Decimal
from typing import Any, Dict, Iterable, Iterator, List, Optional, Set, Tuple, Type, Union, no_type_check

from .. import BaseProvider, ElementsType

TypesNames = List[str]
TypesSpec = Union[List[Type], Tuple[Type, ...]]


class Provider(BaseProvider):
    default_value_types: ElementsType = (
        "str",
        "str",
        "str",
        "str",
        "float",
        "int",
        "int",
        "decimal",
        "date_time",
        "uri",
        "email",
    )

    def _check_signature(self, value_types: Optional[TypesSpec], allowed_types: Optional[TypesSpec]) -> TypesSpec:
        if value_types is not None and not isinstance(value_types, (list, tuple)):
            value_types = (value_types,)
            warnings.warn(
                "Passing `value_types` as positional arguments is going to be "
                "deprecated.  Pass them as a list or tuple instead.",
                PendingDeprecationWarning,
            )
        if allowed_types is not None and not isinstance(allowed_types, (list, tuple)):
            allowed_types = (allowed_types,)
            warnings.warn(
                "Passing `allowed_types` as positional arguments is going to be "
                "deprecated.  Pass them as a list or tuple instead.",
                PendingDeprecationWarning,
            )
        if value_types is None:
            value_types = ()
        if allowed_types is None:
            allowed_types = ()
        return tuple(value_types) + tuple(allowed_types)

    def pybool(self) -> bool:
        return self.random_int(0, 1) == 1

    def pystr(self, min_chars: Optional[int] = None, max_chars: int = 20) -> str:
        """
        Generates a random string of upper and lowercase letters.
        :type min_chars: int
        :type max_chars: int
        :return: String. Random of random length between min and max characters.
        """
        if min_chars is None:
            return "".join(self.random_letters(length=max_chars))
        else:
            assert max_chars >= min_chars, "Maximum length must be greater than or equal to minimum length"
            return "".join(
                self.random_letters(
                    length=self.generator.random.randint(min_chars, max_chars),
                ),
            )

    def pystr_format(
        self,
        string_format: str = "?#-###{{random_int}}{{random_letter}}",
        letters: str = string.ascii_letters,
    ) -> str:
        return self.bothify(self.generator.parse(string_format), letters=letters)

    def pyfloat(
        self,
        left_digits=None,
        right_digits=None,
        positive=False,
        min_value=None,
        max_value=None,
    ):
        if left_digits is not None and left_digits < 0:
            raise ValueError("A float number cannot have less than 0 digits in its " "integer part")
        if right_digits is not None and right_digits < 0:
            raise ValueError("A float number cannot have less than 0 digits in its " "fractional part")
        if left_digits == 0 and right_digits == 0:
            raise ValueError("A float number cannot have less than 0 digits in total")
        if None not in (min_value, max_value) and min_value > max_value:
            raise ValueError("Min value cannot be greater than max value")
        if None not in (min_value, max_value) and min_value == max_value:
            raise ValueError("Min and max value cannot be the same")
        if positive and min_value is not None and min_value <= 0:
            raise ValueError("Cannot combine positive=True with negative or zero min_value")
        if left_digits is not None and max_value and math.ceil(math.log10(abs(max_value))) > left_digits:
            raise ValueError("Max value must fit within left digits")
        if left_digits is not None and min_value and math.ceil(math.log10(abs(min_value))) > left_digits:
            raise ValueError("Min value must fit within left digits")

        # Make sure at least either left or right is set
        if left_digits is None and right_digits is None:
            needed_left_digits = max(1, math.ceil(math.log10(max(abs(max_value or 1), abs(min_value or 1)))))
            right_digits = self.random_int(1, sys.float_info.dig - needed_left_digits)

        # If only one side is set, choose #digits for other side
        if (left_digits is None) ^ (right_digits is None):
            if left_digits is None:
                left_digits = max(1, sys.float_info.dig - right_digits)
            else:
                right_digits = max(1, sys.float_info.dig - left_digits)

        # Make sure we don't ask for too many digits!
        if left_digits + right_digits > sys.float_info.dig:
            raise ValueError(
                f"Asking for too many digits ({left_digits} + {right_digits} == {left_digits + right_digits} > "
                f"{sys.float_info.dig})",
            )

        sign = ""
        if (min_value is not None) or (max_value is not None):
            # Make sure left_digits still respected
            if left_digits is not None:
                if max_value is None:
                    max_value = 10 ** left_digits  # minus smallest representable, adjusted later
                if min_value is None:
                    min_value = -(10 ** left_digits)  # plus smallest representable, adjusted later

            if max_value is not None and max_value < 0:
                max_value += 1  # as the random_int will be generated up to max_value - 1
            if min_value is not None and min_value < 0:
                min_value += 1  # as we then append digits after the left_number
            left_number = self._safe_random_int(
                min_value,
                max_value,
                positive,
            )
        else:
            sign = "+" if positive else self.random_element(("+", "-"))
            left_number = self.random_number(left_digits)

        result = float(f"{sign}{left_number}.{self.random_number(right_digits)}")
        if positive and result == 0:
            if right_digits:
                result = float("0." + "0" * (right_digits - 1) + "1")
            else:
                result += sys.float_info.epsilon

        if right_digits:
            result = min(result, 10 ** left_digits - float(f'0.{"0" * (right_digits - 1)}1'))
            result = max(result, -(10 ** left_digits + float(f'0.{"0" * (right_digits - 1)}1')))
        else:
            result = min(result, 10 ** left_digits - 1)
            result = max(result, -(10 ** left_digits + 1))

        return result

    def _safe_random_int(self, min_value, max_value, positive):
        orig_min_value = min_value
        orig_max_value = max_value

        if min_value is None:
            min_value = max_value - self.random_int()
        if max_value is None:
            max_value = min_value + self.random_int()
        if positive:
            min_value = max(min_value, 0)

        if min_value == max_value:
            return self._safe_random_int(orig_min_value, orig_max_value, positive)
        else:
            return self.random_int(min_value, max_value - 1)

    def pyint(self, min_value: int = 0, max_value: int = 9999, step: int = 1) -> int:
        return self.generator.random_int(min_value, max_value, step=step)

    def pydecimal(
        self,
        left_digits=None,
        right_digits=None,
        positive=False,
        min_value=None,
        max_value=None,
    ):
        if left_digits is not None and left_digits < 0:
            raise ValueError("A decimal number cannot have less than 0 digits in its " "integer part")
        if right_digits is not None and right_digits < 0:
            raise ValueError("A decimal number cannot have less than 0 digits in its " "fractional part")
        if (left_digits is not None and left_digits == 0) and (right_digits is not None and right_digits == 0):
            raise ValueError("A decimal number cannot have 0 digits in total")
        if None not in (min_value, max_value) and min_value > max_value:
            raise ValueError("Min value cannot be greater than max value")
        if None not in (min_value, max_value) and min_value == max_value:
            raise ValueError("Min and max value cannot be the same")
        if positive and min_value is not None and min_value <= 0:
            raise ValueError("Cannot combine positive=True with negative or zero min_value")
        if left_digits is not None and max_value and math.ceil(math.log10(abs(max_value))) > left_digits:
            raise ValueError("Max value must fit within left digits")
        if left_digits is not None and min_value and math.ceil(math.log10(abs(min_value))) > left_digits:
            raise ValueError("Min value must fit within left digits")

        # if either left or right digits are not specified we randomly choose a length
        max_random_digits = 100
        # Because if min_value is bigger than 10**100
        max_digits_from_value = max(
            math.ceil(math.log10(abs(min_value or 1))),
            math.ceil(math.log10(abs(max_value or 1))),
        )
        max_left_random_digits = max(max_random_digits, max_digits_from_value + 10)

        if min_value is not None and min_value >= 0:
            sign = "+"
        elif max_value is not None and max_value <= 0:
            sign = "-"
        else:
            sign = "+" if positive else self.random_element(("+", "-"))

        if sign == "+":
            if max_value is not None:
                left_number = str(self.random_int(max(min_value or 0, 0), max_value))
            else:
                min_left_digits = math.ceil(math.log10(max(min_value or 1, 1)))
                if left_digits is None:
                    left_digits = self.random_int(min_left_digits, max_left_random_digits)
                left_number = "".join([str(self.random_digit()) for i in range(0, left_digits)]) or "0"
        else:
            if min_value is not None:
                left_number = str(self.random_int(max(max_value or 0, 0), abs(min_value)))
            else:
                min_left_digits = math.ceil(math.log10(abs(min(max_value or 1, 1))))
                if left_digits is None:
                    left_digits = self.random_int(min_left_digits, max_left_random_digits)
                left_number = "".join([str(self.random_digit()) for i in range(0, left_digits)]) or "0"

        if right_digits is None:
            right_digits = self.random_int(0, max_random_digits)

        right_number = "".join([str(self.random_digit()) for i in range(0, right_digits)])

        result = Decimal(f"{sign}{left_number}.{right_number}")

        # Because the random result might have the same number of decimals as max_value the random number
        # might be above max_value or below min_value
        if max_value is not None and result > max_value:
            result = Decimal(max_value)
        if min_value is not None and result < min_value:
            result = Decimal(min_value)

        return result

    def pytuple(
        self,
        nb_elements: int = 10,
        variable_nb_elements: bool = True,
        value_types: Optional[TypesSpec] = None,
        allowed_types: Optional[TypesSpec] = None,
    ) -> Tuple[Any, ...]:
        return tuple(
            self._pyiterable(
                nb_elements=nb_elements,
                variable_nb_elements=variable_nb_elements,
                value_types=value_types,
                allowed_types=allowed_types,
            )
        )

    def pyset(
        self,
        nb_elements: int = 10,
        variable_nb_elements: bool = True,
        value_types: Optional[TypesSpec] = None,
        allowed_types: Optional[TypesSpec] = None,
    ) -> Set[Any]:
        return set(
            self._pyiterable(
                nb_elements=nb_elements,
                variable_nb_elements=variable_nb_elements,
                value_types=value_types,
                allowed_types=allowed_types,
            )
        )

    def pylist(
        self,
        nb_elements: int = 10,
        variable_nb_elements: bool = True,
        value_types: Optional[TypesSpec] = None,
        allowed_types: Optional[TypesSpec] = None,
    ) -> List[Any]:
        return list(
            self._pyiterable(
                nb_elements=nb_elements,
                variable_nb_elements=variable_nb_elements,
                value_types=value_types,
                allowed_types=allowed_types,
            )
        )

    @no_type_check
    def pyiterable(
        self,
        nb_elements: int = 10,
        variable_nb_elements: bool = True,
        value_types: Optional[TypesSpec] = None,
        allowed_types: Optional[TypesSpec] = None,
    ) -> Iterable[Any]:
        value_types: TypesSpec = self._check_signature(value_types, allowed_types)
        return self.random_element([self.pylist, self.pytuple, self.pyset])(
            nb_elements=nb_elements,
            variable_nb_elements=variable_nb_elements,
            value_types=value_types,
            allowed_types=allowed_types,
        )

    def _random_type(self, type_list: List[str]) -> str:
        value_type: str = self.random_element(type_list)

        method_name = f"py{value_type}"
        if hasattr(self, method_name):
            value_type = method_name

        return self.generator.format(value_type)

    def _pyiterable(
        self,
        nb_elements: int = 10,
        variable_nb_elements: bool = True,
        value_types: Optional[TypesSpec] = None,
        allowed_types: Optional[TypesSpec] = None,
    ) -> Iterator:

        value_types: TypesSpec = self._check_signature(value_types, allowed_types)

        value_types: TypesNames = [
            t if isinstance(t, str) else getattr(t, "__name__", type(t).__name__).lower()
            for t in value_types
            # avoid recursion
            if t not in ["iterable", "list", "tuple", "dict", "set"]
        ]
        if not value_types:
            value_types = self.default_value_types  # type: ignore

        if variable_nb_elements:
            nb_elements = self.randomize_nb_elements(nb_elements, min=1)

        for _ in range(nb_elements):
            yield self._random_type(value_types)

    def pydict(
        self,
        nb_elements: int = 10,
        variable_nb_elements: bool = True,
        value_types: Optional[TypesSpec] = None,
        allowed_types: Optional[TypesSpec] = None,
    ) -> Dict[Any, Any]:
        """
        Returns a dictionary.

        :nb_elements: number of elements for dictionary
        :variable_nb_elements: is use variable number of elements for dictionary
        :value_types: type of dictionary values
        """
        if variable_nb_elements:
            nb_elements = self.randomize_nb_elements(nb_elements, min=1)

        return dict(
            zip(
                self.generator.words(nb_elements, unique=True),
                self._pyiterable(
                    nb_elements=nb_elements,
                    variable_nb_elements=False,
                    value_types=value_types,
                    allowed_types=allowed_types,
                ),
            )
        )

    def pystruct(
        self, count: int = 10, value_types: Optional[TypesSpec] = None, allowed_types: Optional[TypesSpec] = None
    ) -> Tuple[List, Dict, Dict]:
        value_types: TypesSpec = self._check_signature(value_types, allowed_types)

        value_types: TypesNames = [
            t if isinstance(t, str) else getattr(t, "__name__", type(t).__name__).lower()
            for t in value_types
            # avoid recursion
            if t != "struct"
        ]
        if not value_types:
            value_types = self.default_value_types  # type: ignore

        types = []
        d = {}
        nd = {}
        for i in range(count):
            d[self.generator.word()] = self._random_type(value_types)
            types.append(self._random_type(value_types))
            nd[self.generator.word()] = {
                i: self._random_type(value_types),
                i
                + 1: [
                    self._random_type(value_types),
                    self._random_type(value_types),
                    self._random_type(value_types),
                ],
                i
                + 2: {
                    i: self._random_type(value_types),
                    i + 1: self._random_type(value_types),
                    i
                    + 2: [
                        self._random_type(value_types),
                        self._random_type(value_types),
                    ],
                },
            }
        return types, d, nd



from .. import Provider as PersonProvider


class Provider(PersonProvider):

    # https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes
    language_names = [
        "Afar",
        "Abjasio",
        "Avéstico",
        "Africaans",
        "Akánico",
        "Amhárico",
        "Aragonés",
        "Arábico",
        "Asamés",
        "Avar",
        "Aimara",
        "Azerí",
        "Baskir",
        "Bielorruso",
        "Búlgaro",
        "lenguas Bihari",
        "Bislama",
        "Bambara",
        "Bengalí",
        "Tibetano",
        "Bretón",
        "Bosnio",
        "Catalán",
        "Checheno",
        "Chamorro",
        "Corso",
        "Cree",
        "Checo",
        "Eslavo eclesiástico",
        "Chuvasio",
        "Galés",
        "Danés",
        "Alemán",
        "Maldivo",
        "Dzongkha",
        "Ewé",
        "Griego",
        "Inglés",
        "Esperanto",
        "Español",
        "Estonio",
        "Vasco",
        "Persa",
        "Fula",
        "Finés",
        "Fiyiano",
        "Feroés",
        "Francés",
        "lenguas Frisonas",
        "Irlandés",
        "Gaélico",
        "Gallego",
        "Guaraní",
        "Gujarati",
        "Manés",
        "Hausa",
        "Hebreo",
        "Hindú",
        "Hiri Motu",
        "Croata",
        "Haitiano",
        "Húngaro",
        "Armenio",
        "Herero",
        "Interlingua",
        "Indonés",
        "Igbo",
        "Nuosu",
        "lenguas esquimales",
        "Ido",
        "Islandés",
        "Italiano",
        "Inuit",
        "Japonés",
        "Javanés",
        "Georgiano",
        "Congolés",
        "Kikuyu",
        "Kuanyama",
        "Kazajo",
        "Groenlandés",
        "Camboyano",
        "Canarés",
        "Coreano",
        "Kanurí",
        "Kashmiri Masala",
        "Kurdo",
        "Komi",
        "Córnico",
        "Kirguís",
        "Latín",
        "Luxemburgués",
        "Luganda",
        "Limburgués",
        "Lingala",
        "Lao",
        "Lituano",
        "Kiluba",
        "Letón",
        "Malgache",
        "Marshalés",
        "Maorí",
        "Macedonio",
        "Malabar",
        "Mongol",
        "Marathí",
        "Malayo",
        "Maltés",
        "Birmano",
        "Nauru",
        "Ndebele norte",
        "Nepalí",
        "Ndonga",
        "Neerlandés",
        "Nuevo Noruego",
        "Noruego",
        "Ndebele sur",
        "Navajo",
        "Chichewa",
        "Occitano",
        "Ojibwa",
        "Oromo",
        "Oriya",
        "Osetio",
        "Panyabí",
        "Pali",
        "Polaco",
        "Pastún",
        "Portugués",
        "Quechua",
        "Romanche",
        "Rundi",
        "Rumano",
        "Ruso",
        "Kiñaruanda",
        "Sánscrito",
        "Sardo",
        "Sindi",
        "Sami septentrional",
        "Sango",
        "Cingalés",
        "Eslovaco",
        "Samoano",
        "Shona",
        "Somalí",
        "Albanés",
        "Serbio",
        "Suazi",
        "Sesoto",
        "Sondanés",
        "Sueco",
        "Swahili",
        "Tamil",
        "Télugu",
        "Takiyo",
        "Tailandés",
        "Tigriña",
        "Turcomano",
        "Tagalo",
        "Setsuana",
        "Tongoano",
        "Turco",
        "Tsonga",
        "Tártaro",
        "Tahitiano",
        "Uigur",
        "Ucraniano",
        "Urdu",
        "Uzbeko",
        "Venda",
        "Vietnamita",
        "Valón",
        "Wólof",
        "Xhosa",
        "Yidis",
        "Yoruba",
        "Zhuang",
        "Chino",
        "Zulú",
    ]



from .. import Provider as InternetProvider


class Provider(InternetProvider):
    tlds = (
        # From https://en.wikipedia.org/wiki/List_of_Internet_top-level_domains
        "com",
        "org",
        "net",
        "int",
        "edu",
        "gov",
        "mil",
        # From https://id.wikipedia.org/wiki/.id
        "id",
        "ac.id",
        "biz.id",
        "co.id",
        "desa.id",
        "go.id",
        "mil.id",
        "my.id",
        "net.id",
        "or.id",
        "ponpes.id",
        "sch.id",
        "web.id",
    )



from .. import Provider as DateTimeProvider


class Provider(DateTimeProvider):

    DAY_NAMES = {
        "0": "রবিবার",
        "1": "সোমবার",
        "2": "মঙ্গলবার",
        "3": "বুধবার",
        "4": "বৃহস্পতিবার",
        "5": "শুক্রবার",
        "6": "শনিবার",
    }

    MONTH_NAMES = {
        "01": "জানুয়ারি",
        "02": "ফেব্রুয়ারি",
        "03": "মার্চ",
        "04": "এপ্রিল",
        "05": "মে",
        "06": "জুন",
        "07": "জুলাই",
        "08": "আগস্ট",
        "09": "সেপ্টেম্বর",
        "10": "অক্টোবর",
        "11": "নভেম্বর",
        "12": "ডিসেম্বর",
    }

    def day_of_week(self) -> str:
        day = self.date("%w")
        return self.DAY_NAMES[day]

    def month_name(self) -> str:
        month = self.month()
        return self.MONTH_NAMES[month]
